UNSD — Methodology
Author: United Nations Statistics Division
Description: United Nations Statistics Divisin - Methodology

- United Nations
- Department of Economic and Social Affairs
- Statistics Division

# Methodology

### Standard country or area codes for statistical use (M49) Overview

Global Code | Global Name | Region Code | Region Name | Sub-region Code | Sub-region Name | Intermediate Region Code | Intermediate Region Name | Country or Area | M49 Code | ISO-alpha3 Code | Least Developed Countries (LDC) | Land Locked Developing Countries (LLDC) | Small Island Developing States (SIDS) | Developed / Developing Countries
001 | World | 002 | Africa | 015 | Northern Africa |  |  | Algeria | 012 | DZA |  |  |  | `Developing`
001 | World | 002 | Africa | 015 | Northern Africa |  |  | Egypt | 818 | EGY |  |  |  | `Developing`
001 | World | 002 | Africa | 015 | Northern Africa |  |  | Libya | 434 | LBY |  |  |  | `Developing`
001 | World | 002 | Africa | 015 | Northern Africa |  |  | Morocco | 504 | MAR |  |  |  | `Developing`
001 | World | 002 | Africa | 015 | Northern Africa |  |  | Sudan | 729 | SDN | x |  |  | `Developing`
001 | World | 002 | Africa | 015 | Northern Africa |  |  | Tunisia | 788 | TUN |  |  |  | `Developing`
001 | World | 002 | Africa | 015 | Northern Africa |  |  | Western Sahara | 732 | ESH |  |  |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 014 | Eastern Africa | British Indian Ocean Territory | 086 | IOT |  |  |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 014 | Eastern Africa | Burundi | 108 | BDI | x | x |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 014 | Eastern Africa | Comoros | 174 | COM | x |  | x | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 014 | Eastern Africa | Djibouti | 262 | DJI | x |  |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 014 | Eastern Africa | Eritrea | 232 | ERI | x |  |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 014 | Eastern Africa | Ethiopia | 231 | ETH | x | x |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 014 | Eastern Africa | French Southern Territories | 260 | ATF |  |  |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 014 | Eastern Africa | Kenya | 404 | KEN |  |  |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 014 | Eastern Africa | Madagascar | 450 | MDG | x |  |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 014 | Eastern Africa | Malawi | 454 | MWI | x | x |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 014 | Eastern Africa | Mauritius | 480 | MUS |  |  | x | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 014 | Eastern Africa | Mayotte | 175 | MYT |  |  |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 014 | Eastern Africa | Mozambique | 508 | MOZ | x |  |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 014 | Eastern Africa | Réunion | 638 | REU |  |  |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 014 | Eastern Africa | Rwanda | 646 | RWA | x | x |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 014 | Eastern Africa | Seychelles | 690 | SYC |  |  | x | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 014 | Eastern Africa | Somalia | 706 | SOM | x |  |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 014 | Eastern Africa | South Sudan | 728 | SSD | x | x |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 014 | Eastern Africa | Uganda | 800 | UGA | x | x |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 014 | Eastern Africa | United Republic of Tanzania | 834 | TZA | x |  |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 014 | Eastern Africa | Zambia | 894 | ZMB | x | x |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 014 | Eastern Africa | Zimbabwe | 716 | ZWE |  | x |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 017 | Middle Africa | Angola | 024 | AGO | x |  |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 017 | Middle Africa | Cameroon | 120 | CMR |  |  |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 017 | Middle Africa | Central African Republic | 140 | CAF | x | x |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 017 | Middle Africa | Chad | 148 | TCD | x | x |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 017 | Middle Africa | Congo | 178 | COG |  |  |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 017 | Middle Africa | Democratic Republic of the Congo | 180 | COD | x |  |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 017 | Middle Africa | Equatorial Guinea | 226 | GNQ | x |  |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 017 | Middle Africa | Gabon | 266 | GAB |  |  |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 017 | Middle Africa | Sao Tome and Principe | 678 | STP | x |  | x | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 018 | Southern Africa | Botswana | 072 | BWA |  | x |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 018 | Southern Africa | Lesotho | 426 | LSO | x | x |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 018 | Southern Africa | Namibia | 516 | NAM |  |  |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 018 | Southern Africa | South Africa | 710 | ZAF |  |  |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 018 | Southern Africa | Swaziland | 748 | SWZ |  | x |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 011 | Western Africa | Benin | 204 | BEN | x |  |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 011 | Western Africa | Burkina Faso | 854 | BFA | x | x |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 011 | Western Africa | Cabo Verde | 132 | CPV |  |  | x | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 011 | Western Africa | Côte d'Ivoire | 384 | CIV |  |  |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 011 | Western Africa | Gambia | 270 | GMB | x |  |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 011 | Western Africa | Ghana | 288 | GHA |  |  |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 011 | Western Africa | Guinea | 324 | GIN | x |  |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 011 | Western Africa | Guinea-Bissau | 624 | GNB | x |  | x | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 011 | Western Africa | Liberia | 430 | LBR | x |  |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 011 | Western Africa | Mali | 466 | MLI | x | x |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 011 | Western Africa | Mauritania | 478 | MRT | x |  |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 011 | Western Africa | Niger | 562 | NER | x | x |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 011 | Western Africa | Nigeria | 566 | NGA |  |  |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 011 | Western Africa | Saint Helena | 654 | SHN |  |  |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 011 | Western Africa | Senegal | 686 | SEN | x |  |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 011 | Western Africa | Sierra Leone | 694 | SLE | x |  |  | `Developing`
001 | World | 002 | Africa | 202 | Sub-Saharan Africa | 011 | Western Africa | Togo | 768 | TGO | x |  |  | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 029 | Caribbean | Anguilla | 660 | AIA |  |  | x | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 029 | Caribbean | Antigua and Barbuda | 028 | ATG |  |  | x | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 029 | Caribbean | Aruba | 533 | ABW |  |  | x | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 029 | Caribbean | Bahamas | 044 | BHS |  |  | x | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 029 | Caribbean | Barbados | 052 | BRB |  |  | x | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 029 | Caribbean | Bonaire, Sint Eustatius and Saba | 535 | BES |  |  | x | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 029 | Caribbean | British Virgin Islands | 092 | VGB |  |  | x | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 029 | Caribbean | Cayman Islands | 136 | CYM |  |  |  | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 029 | Caribbean | Cuba | 192 | CUB |  |  | x | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 029 | Caribbean | Curaçao | 531 | CUW |  |  | x | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 029 | Caribbean | Dominica | 212 | DMA |  |  | x | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 029 | Caribbean | Dominican Republic | 214 | DOM |  |  | x | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 029 | Caribbean | Grenada | 308 | GRD |  |  | x | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 029 | Caribbean | Guadeloupe | 312 | GLP |  |  |  | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 029 | Caribbean | Haiti | 332 | HTI | x |  | x | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 029 | Caribbean | Jamaica | 388 | JAM |  |  | x | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 029 | Caribbean | Martinique | 474 | MTQ |  |  |  | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 029 | Caribbean | Montserrat | 500 | MSR |  |  | x | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 029 | Caribbean | Puerto Rico | 630 | PRI |  |  | x | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 029 | Caribbean | Saint Barthélemy | 652 | BLM |  |  |  | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 029 | Caribbean | Saint Kitts and Nevis | 659 | KNA |  |  | x | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 029 | Caribbean | Saint Lucia | 662 | LCA |  |  | x | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 029 | Caribbean | Saint Martin (French Part) | 663 | MAF |  |  |  | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 029 | Caribbean | Saint Vincent and the Grenadines | 670 | VCT |  |  | x | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 029 | Caribbean | Sint Maarten (Dutch part) | 534 | SXM |  |  | x | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 029 | Caribbean | Trinidad and Tobago | 780 | TTO |  |  | x | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 029 | Caribbean | Turks and Caicos Islands | 796 | TCA |  |  |  | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 029 | Caribbean | United States Virgin Islands | 850 | VIR |  |  | x | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 013 | Central America | Belize | 084 | BLZ |  |  | x | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 013 | Central America | Costa Rica | 188 | CRI |  |  |  | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 013 | Central America | El Salvador | 222 | SLV |  |  |  | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 013 | Central America | Guatemala | 320 | GTM |  |  |  | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 013 | Central America | Honduras | 340 | HND |  |  |  | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 013 | Central America | Mexico | 484 | MEX |  |  |  | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 013 | Central America | Nicaragua | 558 | NIC |  |  |  | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 013 | Central America | Panama | 591 | PAN |  |  |  | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 005 | South America | Argentina | 032 | ARG |  |  |  | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 005 | South America | Bolivia (Plurinational State of) | 068 | BOL |  | x |  | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 005 | South America | Bouvet Island | 074 | BVT |  |  |  | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 005 | South America | Brazil | 076 | BRA |  |  |  | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 005 | South America | Chile | 152 | CHL |  |  |  | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 005 | South America | Colombia | 170 | COL |  |  |  | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 005 | South America | Ecuador | 218 | ECU |  |  |  | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 005 | South America | Falkland Islands (Malvinas) | 238 | FLK |  |  |  | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 005 | South America | French Guiana | 254 | GUF |  |  |  | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 005 | South America | Guyana | 328 | GUY |  |  | x | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 005 | South America | Paraguay | 600 | PRY |  | x |  | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 005 | South America | Peru | 604 | PER |  |  |  | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 005 | South America | South Georgia and the South Sandwich Islands | 239 | SGS |  |  |  | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 005 | South America | Suriname | 740 | SUR |  |  | x | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 005 | South America | Uruguay | 858 | URY |  |  |  | `Developing`
001 | World | 019 | Americas | 419 | Latin America and the Caribbean | 005 | South America | Venezuela (Bolivarian Republic of) | 862 | VEN |  |  |  | `Developing`
001 | World | 019 | Americas | 021 | Northern America |  |  | Bermuda | 060 | BMU |  |  |  | `Developed`
001 | World | 019 | Americas | 021 | Northern America |  |  | Canada | 124 | CAN |  |  |  | `Developed`
001 | World | 019 | Americas | 021 | Northern America |  |  | Greenland | 304 | GRL |  |  |  | `Developed`
001 | World | 019 | Americas | 021 | Northern America |  |  | Saint Pierre and Miquelon | 666 | SPM |  |  |  | `Developed`
001 | World | 019 | Americas | 021 | Northern America |  |  | United States of America | 840 | USA |  |  |  | `Developed`
001 | World |  |  |  |  |  |  | Antarctica | 010 | ATA |  |  |  |
001 | World | 142 | Asia | 143 | Central Asia |  |  | Kazakhstan | 398 | KAZ |  | x |  | `Developing`
001 | World | 142 | Asia | 143 | Central Asia |  |  | Kyrgyzstan | 417 | KGZ |  | x |  | `Developing`
001 | World | 142 | Asia | 143 | Central Asia |  |  | Tajikistan | 762 | TJK |  | x |  | `Developing`
001 | World | 142 | Asia | 143 | Central Asia |  |  | Turkmenistan | 795 | TKM |  | x |  | `Developing`
001 | World | 142 | Asia | 143 | Central Asia |  |  | Uzbekistan | 860 | UZB |  | x |  | `Developing`
001 | World | 142 | Asia | 030 | Eastern Asia |  |  | China | 156 | CHN |  |  |  | `Developing`
001 | World | 142 | Asia | 030 | Eastern Asia |  |  | China, Hong Kong Special Administrative Region | 344 | HKG |  |  |  | `Developing`
001 | World | 142 | Asia | 030 | Eastern Asia |  |  | China, Macao Special Administrative Region | 446 | MAC |  |  |  | `Developing`
001 | World | 142 | Asia | 030 | Eastern Asia |  |  | Democratic People's Republic of Korea | 408 | PRK |  |  |  | `Developing`
001 | World | 142 | Asia | 030 | Eastern Asia |  |  | Japan | 392 | JPN |  |  |  | `Developed`
001 | World | 142 | Asia | 030 | Eastern Asia |  |  | Mongolia | 496 | MNG |  | x |  | `Developing`
001 | World | 142 | Asia | 030 | Eastern Asia |  |  | Republic of Korea | 410 | KOR |  |  |  | `Developing`
001 | World | 142 | Asia | 035 | South-eastern Asia |  |  | Brunei Darussalam | 096 | BRN |  |  |  | `Developing`
001 | World | 142 | Asia | 035 | South-eastern Asia |  |  | Cambodia | 116 | KHM | x |  |  | `Developing`
001 | World | 142 | Asia | 035 | South-eastern Asia |  |  | Indonesia | 360 | IDN |  |  |  | `Developing`
001 | World | 142 | Asia | 035 | South-eastern Asia |  |  | Lao People's Democratic Republic | 418 | LAO | x | x |  | `Developing`
001 | World | 142 | Asia | 035 | South-eastern Asia |  |  | Malaysia | 458 | MYS |  |  |  | `Developing`
001 | World | 142 | Asia | 035 | South-eastern Asia |  |  | Myanmar | 104 | MMR | x |  |  | `Developing`
001 | World | 142 | Asia | 035 | South-eastern Asia |  |  | Philippines | 608 | PHL |  |  |  | `Developing`
001 | World | 142 | Asia | 035 | South-eastern Asia |  |  | Singapore | 702 | SGP |  |  | x | `Developing`
001 | World | 142 | Asia | 035 | South-eastern Asia |  |  | Thailand | 764 | THA |  |  |  | `Developing`
001 | World | 142 | Asia | 035 | South-eastern Asia |  |  | Timor-Leste | 626 | TLS | x |  | x | `Developing`
001 | World | 142 | Asia | 035 | South-eastern Asia |  |  | Viet Nam | 704 | VNM |  |  |  | `Developing`
001 | World | 142 | Asia | 034 | Southern Asia |  |  | Afghanistan | 004 | AFG | x | x |  | `Developing`
001 | World | 142 | Asia | 034 | Southern Asia |  |  | Bangladesh | 050 | BGD | x |  |  | `Developing`
001 | World | 142 | Asia | 034 | Southern Asia |  |  | Bhutan | 064 | BTN | x | x |  | `Developing`
001 | World | 142 | Asia | 034 | Southern Asia |  |  | India | 356 | IND |  |  |  | `Developing`
001 | World | 142 | Asia | 034 | Southern Asia |  |  | Iran (Islamic Republic of) | 364 | IRN |  |  |  | `Developing`
001 | World | 142 | Asia | 034 | Southern Asia |  |  | Maldives | 462 | MDV |  |  | x | `Developing`
001 | World | 142 | Asia | 034 | Southern Asia |  |  | Nepal | 524 | NPL | x | x |  | `Developing`
001 | World | 142 | Asia | 034 | Southern Asia |  |  | Pakistan | 586 | PAK |  |  |  | `Developing`
001 | World | 142 | Asia | 034 | Southern Asia |  |  | Sri Lanka | 144 | LKA |  |  |  | `Developing`
001 | World | 142 | Asia | 145 | Western Asia |  |  | Armenia | 051 | ARM |  | x |  | `Developing`
001 | World | 142 | Asia | 145 | Western Asia |  |  | Azerbaijan | 031 | AZE |  | x |  | `Developing`
001 | World | 142 | Asia | 145 | Western Asia |  |  | Bahrain | 048 | BHR |  |  |  | `Developing`
001 | World | 142 | Asia | 145 | Western Asia |  |  | Cyprus | 196 | CYP |  |  |  | `Developing`
001 | World | 142 | Asia | 145 | Western Asia |  |  | Georgia | 268 | GEO |  |  |  | `Developing`
001 | World | 142 | Asia | 145 | Western Asia |  |  | Iraq | 368 | IRQ |  |  |  | `Developing`
001 | World | 142 | Asia | 145 | Western Asia |  |  | Israel | 376 | ISR |  |  |  | `Developing`
001 | World | 142 | Asia | 145 | Western Asia |  |  | Jordan | 400 | JOR |  |  |  | `Developing`
001 | World | 142 | Asia | 145 | Western Asia |  |  | Kuwait | 414 | KWT |  |  |  | `Developing`
001 | World | 142 | Asia | 145 | Western Asia |  |  | Lebanon | 422 | LBN |  |  |  | `Developing`
001 | World | 142 | Asia | 145 | Western Asia |  |  | Oman | 512 | OMN |  |  |  | `Developing`
001 | World | 142 | Asia | 145 | Western Asia |  |  | Qatar | 634 | QAT |  |  |  | `Developing`
001 | World | 142 | Asia | 145 | Western Asia |  |  | Saudi Arabia | 682 | SAU |  |  |  | `Developing`
001 | World | 142 | Asia | 145 | Western Asia |  |  | State of Palestine | 275 | PSE |  |  |  | `Developing`
001 | World | 142 | Asia | 145 | Western Asia |  |  | Syrian Arab Republic | 760 | SYR |  |  |  | `Developing`
001 | World | 142 | Asia | 145 | Western Asia |  |  | Turkey | 792 | TUR |  |  |  | `Developing`
001 | World | 142 | Asia | 145 | Western Asia |  |  | United Arab Emirates | 784 | ARE |  |  |  | `Developing`
001 | World | 142 | Asia | 145 | Western Asia |  |  | Yemen | 887 | YEM | x |  |  | `Developing`
001 | World | 150 | Europe | 151 | Eastern Europe |  |  | Belarus | 112 | BLR |  |  |  | `Developed`
001 | World | 150 | Europe | 151 | Eastern Europe |  |  | Bulgaria | 100 | BGR |  |  |  | `Developed`
001 | World | 150 | Europe | 151 | Eastern Europe |  |  | Czechia | 203 | CZE |  |  |  | `Developed`
001 | World | 150 | Europe | 151 | Eastern Europe |  |  | Hungary | 348 | HUN |  |  |  | `Developed`
001 | World | 150 | Europe | 151 | Eastern Europe |  |  | Poland | 616 | POL |  |  |  | `Developed`
001 | World | 150 | Europe | 151 | Eastern Europe |  |  | Republic of Moldova | 498 | MDA |  | x |  | `Developed`
001 | World | 150 | Europe | 151 | Eastern Europe |  |  | Romania | 642 | ROU |  |  |  | `Developed`
001 | World | 150 | Europe | 151 | Eastern Europe |  |  | Russian Federation | 643 | RUS |  |  |  | `Developed`
001 | World | 150 | Europe | 151 | Eastern Europe |  |  | Slovakia | 703 | SVK |  |  |  | `Developed`
001 | World | 150 | Europe | 151 | Eastern Europe |  |  | Ukraine | 804 | UKR |  |  |  | `Developed`
001 | World | 150 | Europe | 154 | Northern Europe |  |  | Åland Islands | 248 | ALA |  |  |  | `Developed`
001 | World | 150 | Europe | 154 | Northern Europe | 830 | Channel Islands | Guernsey | 831 | GGY |  |  |  | `Developed`
001 | World | 150 | Europe | 154 | Northern Europe | 830 | Channel Islands | Jersey | 832 | JEY |  |  |  | `Developed`
001 | World | 150 | Europe | 154 | Northern Europe | 830 | Channel Islands | Sark | 680 |  |  |  |  | `Developed`
001 | World | 150 | Europe | 154 | Northern Europe |  |  | Denmark | 208 | DNK |  |  |  | `Developed`
001 | World | 150 | Europe | 154 | Northern Europe |  |  | Estonia | 233 | EST |  |  |  | `Developed`
001 | World | 150 | Europe | 154 | Northern Europe |  |  | Faroe Islands | 234 | FRO |  |  |  | `Developed`
001 | World | 150 | Europe | 154 | Northern Europe |  |  | Finland | 246 | FIN |  |  |  | `Developed`
001 | World | 150 | Europe | 154 | Northern Europe |  |  | Iceland | 352 | ISL |  |  |  | `Developed`
001 | World | 150 | Europe | 154 | Northern Europe |  |  | Ireland | 372 | IRL |  |  |  | `Developed`
001 | World | 150 | Europe | 154 | Northern Europe |  |  | Isle of Man | 833 | IMN |  |  |  | `Developed`
001 | World | 150 | Europe | 154 | Northern Europe |  |  | Latvia | 428 | LVA |  |  |  | `Developed`
001 | World | 150 | Europe | 154 | Northern Europe |  |  | Lithuania | 440 | LTU |  |  |  | `Developed`
001 | World | 150 | Europe | 154 | Northern Europe |  |  | Norway | 578 | NOR |  |  |  | `Developed`
001 | World | 150 | Europe | 154 | Northern Europe |  |  | Svalbard and Jan Mayen Islands | 744 | SJM |  |  |  | `Developed`
001 | World | 150 | Europe | 154 | Northern Europe |  |  | Sweden | 752 | SWE |  |  |  | `Developed`
001 | World | 150 | Europe | 154 | Northern Europe |  |  | United Kingdom of Great Britain and Northern Ireland | 826 | GBR |  |  |  | `Developed`
001 | World | 150 | Europe | 039 | Southern Europe |  |  | Albania | 008 | ALB |  |  |  | `Developed`
001 | World | 150 | Europe | 039 | Southern Europe |  |  | Andorra | 020 | AND |  |  |  | `Developed`
001 | World | 150 | Europe | 039 | Southern Europe |  |  | Bosnia and Herzegovina | 070 | BIH |  |  |  | `Developed`
001 | World | 150 | Europe | 039 | Southern Europe |  |  | Croatia | 191 | HRV |  |  |  | `Developed`
001 | World | 150 | Europe | 039 | Southern Europe |  |  | Gibraltar | 292 | GIB |  |  |  | `Developed`
001 | World | 150 | Europe | 039 | Southern Europe |  |  | Greece | 300 | GRC |  |  |  | `Developed`
001 | World | 150 | Europe | 039 | Southern Europe |  |  | Holy See | 336 | VAT |  |  |  | `Developed`
001 | World | 150 | Europe | 039 | Southern Europe |  |  | Italy | 380 | ITA |  |  |  | `Developed`
001 | World | 150 | Europe | 039 | Southern Europe |  |  | Malta | 470 | MLT |  |  |  | `Developed`
001 | World | 150 | Europe | 039 | Southern Europe |  |  | Montenegro | 499 | MNE |  |  |  | `Developed`
001 | World | 150 | Europe | 039 | Southern Europe |  |  | Portugal | 620 | PRT |  |  |  | `Developed`
001 | World | 150 | Europe | 039 | Southern Europe |  |  | San Marino | 674 | SMR |  |  |  | `Developed`
001 | World | 150 | Europe | 039 | Southern Europe |  |  | Serbia | 688 | SRB |  |  |  | `Developed`
001 | World | 150 | Europe | 039 | Southern Europe |  |  | Slovenia | 705 | SVN |  |  |  | `Developed`
001 | World | 150 | Europe | 039 | Southern Europe |  |  | Spain | 724 | ESP |  |  |  | `Developed`
001 | World | 150 | Europe | 039 | Southern Europe |  |  | The former Yugoslav Republic of Macedonia | 807 | MKD |  | x |  | `Developed`
001 | World | 150 | Europe | 155 | Western Europe |  |  | Austria | 040 | AUT |  |  |  | `Developed`
001 | World | 150 | Europe | 155 | Western Europe |  |  | Belgium | 056 | BEL |  |  |  | `Developed`
001 | World | 150 | Europe | 155 | Western Europe |  |  | France | 250 | FRA |  |  |  | `Developed`
001 | World | 150 | Europe | 155 | Western Europe |  |  | Germany | 276 | DEU |  |  |  | `Developed`
001 | World | 150 | Europe | 155 | Western Europe |  |  | Liechtenstein | 438 | LIE |  |  |  | `Developed`
001 | World | 150 | Europe | 155 | Western Europe |  |  | Luxembourg | 442 | LUX |  |  |  | `Developed`
001 | World | 150 | Europe | 155 | Western Europe |  |  | Monaco | 492 | MCO |  |  |  | `Developed`
001 | World | 150 | Europe | 155 | Western Europe |  |  | Netherlands | 528 | NLD |  |  |  | `Developed`
001 | World | 150 | Europe | 155 | Western Europe |  |  | Switzerland | 756 | CHE |  |  |  | `Developed`
001 | World | 009 | Oceania | 053 | Australia and New Zealand |  |  | Australia | 036 | AUS |  |  |  | `Developed`
001 | World | 009 | Oceania | 053 | Australia and New Zealand |  |  | Christmas Island | 162 | CXR |  |  |  | `Developed`
001 | World | 009 | Oceania | 053 | Australia and New Zealand |  |  | Cocos (Keeling) Islands | 166 | CCK |  |  |  | `Developed`
001 | World | 009 | Oceania | 053 | Australia and New Zealand |  |  | Heard Island and McDonald Islands | 334 | HMD |  |  |  | `Developed`
001 | World | 009 | Oceania | 053 | Australia and New Zealand |  |  | New Zealand | 554 | NZL |  |  |  | `Developed`
001 | World | 009 | Oceania | 053 | Australia and New Zealand |  |  | Norfolk Island | 574 | NFK |  |  |  | `Developed`
001 | World | 009 | Oceania | 054 | Melanesia |  |  | Fiji | 242 | FJI |  |  | x | `Developing`
001 | World | 009 | Oceania | 054 | Melanesia |  |  | New Caledonia | 540 | NCL |  |  | x | `Developing`
001 | World | 009 | Oceania | 054 | Melanesia |  |  | Papua New Guinea | 598 | PNG |  |  | x | `Developing`
001 | World | 009 | Oceania | 054 | Melanesia |  |  | Solomon Islands | 090 | SLB | x |  | x | `Developing`
001 | World | 009 | Oceania | 054 | Melanesia |  |  | Vanuatu | 548 | VUT | x |  | x | `Developing`
001 | World | 009 | Oceania | 057 | Micronesia |  |  | Guam | 316 | GUM |  |  | x | `Developing`
001 | World | 009 | Oceania | 057 | Micronesia |  |  | Kiribati | 296 | KIR | x |  | x | `Developing`
001 | World | 009 | Oceania | 057 | Micronesia |  |  | Marshall Islands | 584 | MHL |  |  | x | `Developing`
001 | World | 009 | Oceania | 057 | Micronesia |  |  | Micronesia (Federated States of) | 583 | FSM |  |  | x | `Developing`
001 | World | 009 | Oceania | 057 | Micronesia |  |  | Nauru | 520 | NRU |  |  | x | `Developing`
001 | World | 009 | Oceania | 057 | Micronesia |  |  | Northern Mariana Islands | 580 | MNP |  |  | x | `Developing`
001 | World | 009 | Oceania | 057 | Micronesia |  |  | Palau | 585 | PLW |  |  | x | `Developing`
001 | World | 009 | Oceania | 057 | Micronesia |  |  | United States Minor Outlying Islands | 581 | UMI |  |  |  | `Developing`
001 | World | 009 | Oceania | 061 | Polynesia |  |  | American Samoa | 016 | ASM |  |  | x | `Developing`
001 | World | 009 | Oceania | 061 | Polynesia |  |  | Cook Islands | 184 | COK |  |  | x | `Developing`
001 | World | 009 | Oceania | 061 | Polynesia |  |  | French Polynesia | 258 | PYF |  |  | x | `Developing`
001 | World | 009 | Oceania | 061 | Polynesia |  |  | Niue | 570 | NIU |  |  | x | `Developing`
001 | World | 009 | Oceania | 061 | Polynesia |  |  | Pitcairn | 612 | PCN |  |  |  | `Developing`
001 | World | 009 | Oceania | 061 | Polynesia |  |  | Samoa | 882 | WSM |  |  | x | `Developing`
001 | World | 009 | Oceania | 061 | Polynesia |  |  | Tokelau | 772 | TKL |  |  |  | `Developing`
001 | World | 009 | Oceania | 061 | Polynesia |  |  | Tonga | 776 | TON |  |  | x | `Developing`
001 | World | 009 | Oceania | 061 | Polynesia |  |  | Tuvalu | 798 | TUV | x |  | x | `Developing`
001 | World | 009 | Oceania | 061 | Polynesia |  |  | Wallis and Futuna Islands | 876 | WLF |  |  |  | `Developing`

Global Code | Global Name | Region Code | Region Name | Sub-region Code | Sub-region Name | Intermediate Region Code | Intermediate Region Name | Country or Area | M49 Code | ISO-alpha3 Code | Least Developed Countries (LDC) | Land Locked Developing Countries (LLDC) | Small Island Developing States (SIDS) | Developed / Developing Countries
001 | 世界 | 002 | 非洲 | 015 | 北非 |  |  | 阿尔及利亚 | 012 | DZA |  |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 015 | 北非 |  |  | 埃及 | 818 | EGY |  |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 015 | 北非 |  |  | 利比亚 | 434 | LBY |  |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 015 | 北非 |  |  | 摩洛哥 | 504 | MAR |  |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 015 | 北非 |  |  | 苏丹 | 729 | SDN | x |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 015 | 北非 |  |  | 突尼斯 | 788 | TUN |  |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 015 | 北非 |  |  | 西撒哈拉 | 732 | ESH |  |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 014 | 东非 | 英属印度洋领土 | 086 | IOT |  |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 014 | 东非 | 布隆迪 | 108 | BDI | x | x |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 014 | 东非 | 科摩罗 | 174 | COM | x |  | x | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 014 | 东非 | 吉布提 | 262 | DJI | x |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 014 | 东非 | 厄立特里亚 | 232 | ERI | x |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 014 | 东非 | 埃塞俄比亚 | 231 | ETH | x | x |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 014 | 东非 | 法属南方领地 | 260 | ATF |  |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 014 | 东非 | 肯尼亚 | 404 | KEN |  |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 014 | 东非 | 马达加斯加 | 450 | MDG | x |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 014 | 东非 | 马拉维 | 454 | MWI | x | x |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 014 | 东非 | 毛里求斯 | 480 | MUS |  |  | x | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 014 | 东非 | 马约特 | 175 | MYT |  |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 014 | 东非 | 莫桑比克 | 508 | MOZ | x |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 014 | 东非 | 留尼汪 | 638 | REU |  |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 014 | 东非 | 卢旺达 | 646 | RWA | x | x |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 014 | 东非 | 塞舌尔 | 690 | SYC |  |  | x | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 014 | 东非 | 索马里 | 706 | SOM | x |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 014 | 东非 | 南苏丹 | 728 | SSD | x | x |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 014 | 东非 | 乌干达 | 800 | UGA | x | x |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 014 | 东非 | 坦桑尼亚联合共和国 | 834 | TZA | x |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 014 | 东非 | 赞比亚 | 894 | ZMB | x | x |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 014 | 东非 | 津巴布韦 | 716 | ZWE |  | x |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 017 | 中非 | 安哥拉 | 024 | AGO | x |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 017 | 中非 | 喀麦隆 | 120 | CMR |  |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 017 | 中非 | 中非共和国 | 140 | CAF | x | x |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 017 | 中非 | 乍得 | 148 | TCD | x | x |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 017 | 中非 | 刚果 | 178 | COG |  |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 017 | 中非 | 刚果民主共和国 | 180 | COD | x |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 017 | 中非 | 赤道几内亚 | 226 | GNQ | x |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 017 | 中非 | 加蓬 | 266 | GAB |  |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 017 | 中非 | 圣多美和普林西比 | 678 | STP | x |  | x | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 018 | 南部非洲 | 博茨瓦纳 | 072 | BWA |  | x |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 018 | 南部非洲 | 莱索托 | 426 | LSO | x | x |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 018 | 南部非洲 | 纳米比亚 | 516 | NAM |  |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 018 | 南部非洲 | 南非 | 710 | ZAF |  |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 018 | 南部非洲 | 斯威士兰 | 748 | SWZ |  | x |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 011 | 西非 | 贝宁 | 204 | BEN | x |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 011 | 西非 | 布基纳法索 | 854 | BFA | x | x |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 011 | 西非 | 佛得角 | 132 | CPV |  |  | x | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 011 | 西非 | 科特迪瓦 | 384 | CIV |  |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 011 | 西非 | 冈比亚 | 270 | GMB | x |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 011 | 西非 | 加纳 | 288 | GHA |  |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 011 | 西非 | 几内亚 | 324 | GIN | x |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 011 | 西非 | 几内亚比绍 | 624 | GNB | x |  | x | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 011 | 西非 | 利比里亚 | 430 | LBR | x |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 011 | 西非 | 马里 | 466 | MLI | x | x |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 011 | 西非 | 毛里塔尼亚 | 478 | MRT | x |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 011 | 西非 | 尼日尔 | 562 | NER | x | x |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 011 | 西非 | 尼日利亚 | 566 | NGA |  |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 011 | 西非 | 圣赫勒拿 | 654 | SHN |  |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 011 | 西非 | 塞内加尔 | 686 | SEN | x |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 011 | 西非 | 塞拉利昂 | 694 | SLE | x |  |  | `Developing`
001 | 世界 | 002 | 非洲 | 202 | 撒哈拉以南非洲 | 011 | 西非 | 多哥 | 768 | TGO | x |  |  | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 029 | 加勒比 | 安圭拉 | 660 | AIA |  |  | x | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 029 | 加勒比 | 安提瓜和巴布达 | 028 | ATG |  |  | x | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 029 | 加勒比 | 阿鲁巴 | 533 | ABW |  |  | x | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 029 | 加勒比 | 巴哈马 | 044 | BHS |  |  | x | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 029 | 加勒比 | 巴巴多斯 | 052 | BRB |  |  | x | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 029 | 加勒比 | 博纳尔,圣俄斯塔休斯和萨巴 | 535 | BES |  |  | x | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 029 | 加勒比 | 英属维尔京群岛 | 092 | VGB |  |  | x | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 029 | 加勒比 | 开曼群岛 | 136 | CYM |  |  |  | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 029 | 加勒比 | 古巴 | 192 | CUB |  |  | x | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 029 | 加勒比 | 库拉索 | 531 | CUW |  |  | x | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 029 | 加勒比 | 多米尼克 | 212 | DMA |  |  | x | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 029 | 加勒比 | 多米尼加 | 214 | DOM |  |  | x | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 029 | 加勒比 | 格林纳达 | 308 | GRD |  |  | x | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 029 | 加勒比 | 瓜德罗普 | 312 | GLP |  |  |  | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 029 | 加勒比 | 海地 | 332 | HTI | x |  | x | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 029 | 加勒比 | 牙买加 | 388 | JAM |  |  | x | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 029 | 加勒比 | 马提尼克 | 474 | MTQ |  |  |  | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 029 | 加勒比 | 蒙特塞拉特 | 500 | MSR |  |  | x | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 029 | 加勒比 | 波多黎各 | 630 | PRI |  |  | x | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 029 | 加勒比 | 圣巴泰勒米 | 652 | BLM |  |  |  | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 029 | 加勒比 | 圣基茨和尼维斯 | 659 | KNA |  |  | x | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 029 | 加勒比 | 圣卢西亚 | 662 | LCA |  |  | x | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 029 | 加勒比 | 圣马丁(法属) | 663 | MAF |  |  |  | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 029 | 加勒比 | 圣文森特和格林纳丁斯 | 670 | VCT |  |  | x | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 029 | 加勒比 | 圣马丁(荷属) | 534 | SXM |  |  | x | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 029 | 加勒比 | 特立尼达和多巴哥 | 780 | TTO |  |  | x | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 029 | 加勒比 | 特克斯和凯科斯群岛 | 796 | TCA |  |  |  | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 029 | 加勒比 | 美属维尔京群岛 | 850 | VIR |  |  | x | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 013 | 中美洲 | 伯利兹 | 084 | BLZ |  |  | x | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 013 | 中美洲 | 哥斯达黎加 | 188 | CRI |  |  |  | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 013 | 中美洲 | 萨尔瓦多 | 222 | SLV |  |  |  | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 013 | 中美洲 | 危地马拉 | 320 | GTM |  |  |  | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 013 | 中美洲 | 洪都拉斯 | 340 | HND |  |  |  | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 013 | 中美洲 | 墨西哥 | 484 | MEX |  |  |  | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 013 | 中美洲 | 尼加拉瓜 | 558 | NIC |  |  |  | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 013 | 中美洲 | 巴拿马 | 591 | PAN |  |  |  | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 005 | 南美洲 | 阿根廷 | 032 | ARG |  |  |  | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 005 | 南美洲 | 玻利维亚(多民族国) | 068 | BOL |  | x |  | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 005 | 南美洲 | 布维岛 | 074 | BVT |  |  |  | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 005 | 南美洲 | 巴西 | 076 | BRA |  |  |  | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 005 | 南美洲 | 智利 | 152 | CHL |  |  |  | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 005 | 南美洲 | 哥伦比亚 | 170 | COL |  |  |  | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 005 | 南美洲 | 厄瓜多尔 | 218 | ECU |  |  |  | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 005 | 南美洲 | 福克兰群岛(马尔维纳斯) | 238 | FLK |  |  |  | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 005 | 南美洲 | 法属圭亚那 | 254 | GUF |  |  |  | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 005 | 南美洲 | 圭亚那 | 328 | GUY |  |  | x | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 005 | 南美洲 | 巴拉圭 | 600 | PRY |  | x |  | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 005 | 南美洲 | 秘鲁 | 604 | PER |  |  |  | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 005 | 南美洲 | 南乔治亚岛和南桑德韦奇岛 | 239 | SGS |  |  |  | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 005 | 南美洲 | 苏里南 | 740 | SUR |  |  | x | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 005 | 南美洲 | 乌拉圭 | 858 | URY |  |  |  | `Developing`
001 | 世界 | 019 | 美洲 | 419 | 拉丁美洲和加勒比 | 005 | 南美洲 | 委内瑞拉(玻利瓦尔共和国) | 862 | VEN |  |  |  | `Developing`
001 | 世界 | 019 | 美洲 | 021 | 北美 |  |  | 百慕大 | 060 | BMU |  |  |  | `Developed`
001 | 世界 | 019 | 美洲 | 021 | 北美 |  |  | 加拿大 | 124 | CAN |  |  |  | `Developed`
001 | 世界 | 019 | 美洲 | 021 | 北美 |  |  | 格陵兰 | 304 | GRL |  |  |  | `Developed`
001 | 世界 | 019 | 美洲 | 021 | 北美 |  |  | 圣皮埃尔和密克隆 | 666 | SPM |  |  |  | `Developed`
001 | 世界 | 019 | 美洲 | 021 | 北美 |  |  | 美利坚合众国 | 840 | USA |  |  |  | `Developed`
001 | 世界 |  |  |  |  |  |  | 南极洲 | 010 | ATA |  |  |  |
001 | 世界 | 142 | 亚洲 | 143 | 中亚 |  |  | 哈萨克斯坦 | 398 | KAZ |  | x |  | `Developing`
001 | 世界 | 142 | 亚洲 | 143 | 中亚 |  |  | 吉尔吉斯斯坦 | 417 | KGZ |  | x |  | `Developing`
001 | 世界 | 142 | 亚洲 | 143 | 中亚 |  |  | 塔吉克斯坦 | 762 | TJK |  | x |  | `Developing`
001 | 世界 | 142 | 亚洲 | 143 | 中亚 |  |  | 土库曼斯坦 | 795 | TKM |  | x |  | `Developing`
001 | 世界 | 142 | 亚洲 | 143 | 中亚 |  |  | 乌兹别克斯坦 | 860 | UZB |  | x |  | `Developing`
001 | 世界 | 142 | 亚洲 | 030 | 东亚 |  |  | 中国 | 156 | CHN |  |  |  | `Developing`
001 | 世界 | 142 | 亚洲 | 030 | 东亚 |  |  | 中国香港特别行政区 | 344 | HKG |  |  |  | `Developing`
001 | 世界 | 142 | 亚洲 | 030 | 东亚 |  |  | 中国澳门特别行政区 | 446 | MAC |  |  |  | `Developing`
001 | 世界 | 142 | 亚洲 | 030 | 东亚 |  |  | 朝鲜民主主义人民共和国 | 408 | PRK |  |  |  | `Developing`
001 | 世界 | 142 | 亚洲 | 030 | 东亚 |  |  | 日本 | 392 | JPN |  |  |  | `Developed`
001 | 世界 | 142 | 亚洲 | 030 | 东亚 |  |  | 蒙古 | 496 | MNG |  | x |  | `Developing`
001 | 世界 | 142 | 亚洲 | 030 | 东亚 |  |  | 大韩民国 | 410 | KOR |  |  |  | `Developing`
001 | 世界 | 142 | 亚洲 | 035 | 东南亚 |  |  | 文莱达鲁萨兰国 | 096 | BRN |  |  |  | `Developing`
001 | 世界 | 142 | 亚洲 | 035 | 东南亚 |  |  | 柬埔寨 | 116 | KHM | x |  |  | `Developing`
001 | 世界 | 142 | 亚洲 | 035 | 东南亚 |  |  | 印度尼西亚 | 360 | IDN |  |  |  | `Developing`
001 | 世界 | 142 | 亚洲 | 035 | 东南亚 |  |  | 老挝人民民主共和国 | 418 | LAO | x | x |  | `Developing`
001 | 世界 | 142 | 亚洲 | 035 | 东南亚 |  |  | 马来西亚 | 458 | MYS |  |  |  | `Developing`
001 | 世界 | 142 | 亚洲 | 035 | 东南亚 |  |  | 缅甸 | 104 | MMR | x |  |  | `Developing`
001 | 世界 | 142 | 亚洲 | 035 | 东南亚 |  |  | 菲律宾 | 608 | PHL |  |  |  | `Developing`
001 | 世界 | 142 | 亚洲 | 035 | 东南亚 |  |  | 新加坡 | 702 | SGP |  |  | x | `Developing`
001 | 世界 | 142 | 亚洲 | 035 | 东南亚 |  |  | 泰国 | 764 | THA |  |  |  | `Developing`
001 | 世界 | 142 | 亚洲 | 035 | 东南亚 |  |  | 东帝汶 | 626 | TLS | x |  | x | `Developing`
001 | 世界 | 142 | 亚洲 | 035 | 东南亚 |  |  | 越南 | 704 | VNM |  |  |  | `Developing`
001 | 世界 | 142 | 亚洲 | 034 | 南亚 |  |  | 阿富汗 | 004 | AFG | x | x |  | `Developing`
001 | 世界 | 142 | 亚洲 | 034 | 南亚 |  |  | 孟加拉国 | 050 | BGD | x |  |  | `Developing`
001 | 世界 | 142 | 亚洲 | 034 | 南亚 |  |  | 不丹 | 064 | BTN | x | x |  | `Developing`
001 | 世界 | 142 | 亚洲 | 034 | 南亚 |  |  | 印度 | 356 | IND |  |  |  | `Developing`
001 | 世界 | 142 | 亚洲 | 034 | 南亚 |  |  | 伊朗(伊斯兰共和国) | 364 | IRN |  |  |  | `Developing`
001 | 世界 | 142 | 亚洲 | 034 | 南亚 |  |  | 马尔代夫 | 462 | MDV |  |  | x | `Developing`
001 | 世界 | 142 | 亚洲 | 034 | 南亚 |  |  | 尼泊尔 | 524 | NPL | x | x |  | `Developing`
001 | 世界 | 142 | 亚洲 | 034 | 南亚 |  |  | 巴基斯坦 | 586 | PAK |  |  |  | `Developing`
001 | 世界 | 142 | 亚洲 | 034 | 南亚 |  |  | 斯里兰卡 | 144 | LKA |  |  |  | `Developing`
001 | 世界 | 142 | 亚洲 | 145 | 西亚 |  |  | 亚美尼亚 | 051 | ARM |  | x |  | `Developing`
001 | 世界 | 142 | 亚洲 | 145 | 西亚 |  |  | 阿塞拜疆 | 031 | AZE |  | x |  | `Developing`
001 | 世界 | 142 | 亚洲 | 145 | 西亚 |  |  | 巴林 | 048 | BHR |  |  |  | `Developing`
001 | 世界 | 142 | 亚洲 | 145 | 西亚 |  |  | 塞浦路斯 | 196 | CYP |  |  |  | `Developing`
001 | 世界 | 142 | 亚洲 | 145 | 西亚 |  |  | 格鲁吉亚 | 268 | GEO |  |  |  | `Developing`
001 | 世界 | 142 | 亚洲 | 145 | 西亚 |  |  | 伊拉克 | 368 | IRQ |  |  |  | `Developing`
001 | 世界 | 142 | 亚洲 | 145 | 西亚 |  |  | 以色列 | 376 | ISR |  |  |  | `Developing`
001 | 世界 | 142 | 亚洲 | 145 | 西亚 |  |  | 约旦 | 400 | JOR |  |  |  | `Developing`
001 | 世界 | 142 | 亚洲 | 145 | 西亚 |  |  | 科威特 | 414 | KWT |  |  |  | `Developing`
001 | 世界 | 142 | 亚洲 | 145 | 西亚 |  |  | 黎巴嫩 | 422 | LBN |  |  |  | `Developing`
001 | 世界 | 142 | 亚洲 | 145 | 西亚 |  |  | 阿曼 | 512 | OMN |  |  |  | `Developing`
001 | 世界 | 142 | 亚洲 | 145 | 西亚 |  |  | 卡塔尔 | 634 | QAT |  |  |  | `Developing`
001 | 世界 | 142 | 亚洲 | 145 | 西亚 |  |  | 沙特阿拉伯 | 682 | SAU |  |  |  | `Developing`
001 | 世界 | 142 | 亚洲 | 145 | 西亚 |  |  | 巴勒斯坦国 | 275 | PSE |  |  |  | `Developing`
001 | 世界 | 142 | 亚洲 | 145 | 西亚 |  |  | 阿拉伯叙利亚共和国 | 760 | SYR |  |  |  | `Developing`
001 | 世界 | 142 | 亚洲 | 145 | 西亚 |  |  | 土耳其 | 792 | TUR |  |  |  | `Developing`
001 | 世界 | 142 | 亚洲 | 145 | 西亚 |  |  | 阿拉伯联合酋长国 | 784 | ARE |  |  |  | `Developing`
001 | 世界 | 142 | 亚洲 | 145 | 西亚 |  |  | 也门 | 887 | YEM | x |  |  | `Developing`
001 | 世界 | 150 | 欧洲 | 151 | 东欧 |  |  | 白俄罗斯 | 112 | BLR |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 151 | 东欧 |  |  | 保加利亚 | 100 | BGR |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 151 | 东欧 |  |  | 捷克 | 203 | CZE |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 151 | 东欧 |  |  | 匈牙利 | 348 | HUN |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 151 | 东欧 |  |  | 波兰 | 616 | POL |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 151 | 东欧 |  |  | 摩尔多瓦共和国 | 498 | MDA |  | x |  | `Developed`
001 | 世界 | 150 | 欧洲 | 151 | 东欧 |  |  | 罗马尼亚 | 642 | ROU |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 151 | 东欧 |  |  | 俄罗斯联邦 | 643 | RUS |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 151 | 东欧 |  |  | 斯洛伐克 | 703 | SVK |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 151 | 东欧 |  |  | 乌克兰 | 804 | UKR |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 154 | 北欧 |  |  | 奥兰群岛 | 248 | ALA |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 154 | 北欧 | 830 | 海峡群岛 | 根西 | 831 | GGY |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 154 | 北欧 | 830 | 海峡群岛 | 泽西 | 832 | JEY |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 154 | 北欧 | 830 | 海峡群岛 | 萨克 | 680 |  |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 154 | 北欧 |  |  | 丹麦 | 208 | DNK |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 154 | 北欧 |  |  | 爱沙尼亚 | 233 | EST |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 154 | 北欧 |  |  | 法罗群岛 | 234 | FRO |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 154 | 北欧 |  |  | 芬兰 | 246 | FIN |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 154 | 北欧 |  |  | 冰岛 | 352 | ISL |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 154 | 北欧 |  |  | 爱尔兰 | 372 | IRL |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 154 | 北欧 |  |  | 马恩岛 | 833 | IMN |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 154 | 北欧 |  |  | 拉脱维亚 | 428 | LVA |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 154 | 北欧 |  |  | 立陶宛 | 440 | LTU |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 154 | 北欧 |  |  | 挪威 | 578 | NOR |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 154 | 北欧 |  |  | 斯瓦尔巴岛和扬马延岛 | 744 | SJM |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 154 | 北欧 |  |  | 瑞典 | 752 | SWE |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 154 | 北欧 |  |  | 大不列颠及北爱尔兰联合王国 | 826 | GBR |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 039 | 南欧 |  |  | 阿尔巴尼亚 | 008 | ALB |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 039 | 南欧 |  |  | 安道尔 | 020 | AND |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 039 | 南欧 |  |  | 波斯尼亚和黑塞哥维那 | 070 | BIH |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 039 | 南欧 |  |  | 克罗地亚 | 191 | HRV |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 039 | 南欧 |  |  | 直布罗陀 | 292 | GIB |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 039 | 南欧 |  |  | 希腊 | 300 | GRC |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 039 | 南欧 |  |  | 教廷 | 336 | VAT |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 039 | 南欧 |  |  | 意大利 | 380 | ITA |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 039 | 南欧 |  |  | 马耳他 | 470 | MLT |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 039 | 南欧 |  |  | 黑山 | 499 | MNE |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 039 | 南欧 |  |  | 葡萄牙 | 620 | PRT |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 039 | 南欧 |  |  | 圣马力诺 | 674 | SMR |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 039 | 南欧 |  |  | 塞尔维亚 | 688 | SRB |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 039 | 南欧 |  |  | 斯洛文尼亚 | 705 | SVN |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 039 | 南欧 |  |  | 西班牙 | 724 | ESP |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 039 | 南欧 |  |  | 前南斯拉夫的马其顿共和国 | 807 | MKD |  | x |  | `Developed`
001 | 世界 | 150 | 欧洲 | 155 | 西欧 |  |  | 奥地利 | 040 | AUT |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 155 | 西欧 |  |  | 比利时 | 056 | BEL |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 155 | 西欧 |  |  | 法国 | 250 | FRA |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 155 | 西欧 |  |  | 德国 | 276 | DEU |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 155 | 西欧 |  |  | 列支敦士登 | 438 | LIE |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 155 | 西欧 |  |  | 卢森堡 | 442 | LUX |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 155 | 西欧 |  |  | 摩纳哥 | 492 | MCO |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 155 | 西欧 |  |  | 荷兰 | 528 | NLD |  |  |  | `Developed`
001 | 世界 | 150 | 欧洲 | 155 | 西欧 |  |  | 瑞士 | 756 | CHE |  |  |  | `Developed`
001 | 世界 | 009 | 大洋洲 | 053 | 澳大利亚和新西兰 |  |  | 澳大利亚 | 036 | AUS |  |  |  | `Developed`
001 | 世界 | 009 | 大洋洲 | 053 | 澳大利亚和新西兰 |  |  | 圣诞岛 | 162 | CXR |  |  |  | `Developed`
001 | 世界 | 009 | 大洋洲 | 053 | 澳大利亚和新西兰 |  |  | 科科斯(基林)群岛 | 166 | CCK |  |  |  | `Developed`
001 | 世界 | 009 | 大洋洲 | 053 | 澳大利亚和新西兰 |  |  | 赫德岛和麦克唐纳岛 | 334 | HMD |  |  |  | `Developed`
001 | 世界 | 009 | 大洋洲 | 053 | 澳大利亚和新西兰 |  |  | 新西兰 | 554 | NZL |  |  |  | `Developed`
001 | 世界 | 009 | 大洋洲 | 053 | 澳大利亚和新西兰 |  |  | 诺福克岛 | 574 | NFK |  |  |  | `Developed`
001 | 世界 | 009 | 大洋洲 | 054 | 美拉尼西亚 |  |  | 斐济 | 242 | FJI |  |  | x | `Developing`
001 | 世界 | 009 | 大洋洲 | 054 | 美拉尼西亚 |  |  | 新喀里多尼亚 | 540 | NCL |  |  | x | `Developing`
001 | 世界 | 009 | 大洋洲 | 054 | 美拉尼西亚 |  |  | 巴布亚新几内亚 | 598 | PNG |  |  | x | `Developing`
001 | 世界 | 009 | 大洋洲 | 054 | 美拉尼西亚 |  |  | 所罗门群岛 | 090 | SLB | x |  | x | `Developing`
001 | 世界 | 009 | 大洋洲 | 054 | 美拉尼西亚 |  |  | 瓦努阿图 | 548 | VUT | x |  | x | `Developing`
001 | 世界 | 009 | 大洋洲 | 057 | 密克罗尼西亚 |  |  | 关岛 | 316 | GUM |  |  | x | `Developing`
001 | 世界 | 009 | 大洋洲 | 057 | 密克罗尼西亚 |  |  | 基里巴斯 | 296 | KIR | x |  | x | `Developing`
001 | 世界 | 009 | 大洋洲 | 057 | 密克罗尼西亚 |  |  | 马绍尔群岛 | 584 | MHL |  |  | x | `Developing`
001 | 世界 | 009 | 大洋洲 | 057 | 密克罗尼西亚 |  |  | 密克罗尼西亚(联邦) | 583 | FSM |  |  | x | `Developing`
001 | 世界 | 009 | 大洋洲 | 057 | 密克罗尼西亚 |  |  | 瑙鲁 | 520 | NRU |  |  | x | `Developing`
001 | 世界 | 009 | 大洋洲 | 057 | 密克罗尼西亚 |  |  | 北马里亚纳群岛 | 580 | MNP |  |  | x | `Developing`
001 | 世界 | 009 | 大洋洲 | 057 | 密克罗尼西亚 |  |  | 帕劳 | 585 | PLW |  |  | x | `Developing`
001 | 世界 | 009 | 大洋洲 | 057 | 密克罗尼西亚 |  |  | 美国本土外小岛屿 | 581 | UMI |  |  |  | `Developing`
001 | 世界 | 009 | 大洋洲 | 061 | 波利尼西亚 |  |  | 美属萨摩亚 | 016 | ASM |  |  | x | `Developing`
001 | 世界 | 009 | 大洋洲 | 061 | 波利尼西亚 |  |  | 库克群岛 | 184 | COK |  |  | x | `Developing`
001 | 世界 | 009 | 大洋洲 | 061 | 波利尼西亚 |  |  | 法属波利尼西亚 | 258 | PYF |  |  | x | `Developing`
001 | 世界 | 009 | 大洋洲 | 061 | 波利尼西亚 |  |  | 纽埃 | 570 | NIU |  |  | x | `Developing`
001 | 世界 | 009 | 大洋洲 | 061 | 波利尼西亚 |  |  | 皮特凯恩 | 612 | PCN |  |  |  | `Developing`
001 | 世界 | 009 | 大洋洲 | 061 | 波利尼西亚 |  |  | 萨摩亚 | 882 | WSM |  |  | x | `Developing`
001 | 世界 | 009 | 大洋洲 | 061 | 波利尼西亚 |  |  | 托克劳 | 772 | TKL |  |  |  | `Developing`
001 | 世界 | 009 | 大洋洲 | 061 | 波利尼西亚 |  |  | 汤加 | 776 | TON |  |  | x | `Developing`
001 | 世界 | 009 | 大洋洲 | 061 | 波利尼西亚 |  |  | 图瓦卢 | 798 | TUV | x |  | x | `Developing`
001 | 世界 | 009 | 大洋洲 | 061 | 波利尼西亚 |  |  | 瓦利斯群岛和富图纳群岛 | 876 | WLF |  |  |  | `Developing`

Global Code | Global Name | Region Code | Region Name | Sub-region Code | Sub-region Name | Intermediate Region Code | Intermediate Region Name | Country or Area | M49 Code | ISO-alpha3 Code | Least Developed Countries (LDC) | Land Locked Developing Countries (LLDC) | Small Island Developing States (SIDS) | Developed / Developing Countries
001 | Весь мир | 002 | Африка | 015 | Северная Африка |  |  | Алжир | 012 | DZA |  |  |  | `Developing`
001 | Весь мир | 002 | Африка | 015 | Северная Африка |  |  | Египет | 818 | EGY |  |  |  | `Developing`
001 | Весь мир | 002 | Африка | 015 | Северная Африка |  |  | Ливия | 434 | LBY |  |  |  | `Developing`
001 | Весь мир | 002 | Африка | 015 | Северная Африка |  |  | Марокко | 504 | MAR |  |  |  | `Developing`
001 | Весь мир | 002 | Африка | 015 | Северная Африка |  |  | Судан | 729 | SDN | x |  |  | `Developing`
001 | Весь мир | 002 | Африка | 015 | Северная Африка |  |  | Тунис | 788 | TUN |  |  |  | `Developing`
001 | Весь мир | 002 | Африка | 015 | Северная Африка |  |  | Западная Сахара | 732 | ESH |  |  |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 014 | Восточная Африка | Британская территория в Индийском океане | 086 | IOT |  |  |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 014 | Восточная Африка | Бурунди | 108 | BDI | x | x |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 014 | Восточная Африка | Коморские Острова | 174 | COM | x |  | x | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 014 | Восточная Африка | Джибути | 262 | DJI | x |  |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 014 | Восточная Африка | Эритрея | 232 | ERI | x |  |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 014 | Восточная Африка | Эфиопия | 231 | ETH | x | x |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 014 | Восточная Африка | Южные земли (французская заморская территория) | 260 | ATF |  |  |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 014 | Восточная Африка | Кения | 404 | KEN |  |  |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 014 | Восточная Африка | Мадагаскар | 450 | MDG | x |  |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 014 | Восточная Африка | Малави | 454 | MWI | x | x |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 014 | Восточная Африка | Маврикий | 480 | MUS |  |  | x | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 014 | Восточная Африка | Острове Майотта | 175 | MYT |  |  |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 014 | Восточная Африка | Мозамбик | 508 | MOZ | x |  |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 014 | Восточная Африка | Реюньон | 638 | REU |  |  |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 014 | Восточная Африка | Руанда | 646 | RWA | x | x |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 014 | Восточная Африка | Сейшельские Острова | 690 | SYC |  |  | x | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 014 | Восточная Африка | Сомали | 706 | SOM | x |  |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 014 | Восточная Африка | Южный Судан | 728 | SSD | x | x |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 014 | Восточная Африка | Уганда | 800 | UGA | x | x |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 014 | Восточная Африка | Объединенная Республика Танзания | 834 | TZA | x |  |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 014 | Восточная Африка | Замбия | 894 | ZMB | x | x |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 014 | Восточная Африка | Зимбабве | 716 | ZWE |  | x |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 017 | Центральная Африка | Ангола | 024 | AGO | x |  |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 017 | Центральная Африка | Камерун | 120 | CMR |  |  |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 017 | Центральная Африка | Центральноафриканская Республика | 140 | CAF | x | x |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 017 | Центральная Африка | Чад | 148 | TCD | x | x |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 017 | Центральная Африка | Конго | 178 | COG |  |  |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 017 | Центральная Африка | Демократическая Республика Конго | 180 | COD | x |  |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 017 | Центральная Африка | Экваториальная Гвинея | 226 | GNQ | x |  |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 017 | Центральная Африка | Габон | 266 | GAB |  |  |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 017 | Центральная Африка | Сан-Томе и Принсипи | 678 | STP | x |  | x | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 018 | Южная часть Африки | Ботсвана | 072 | BWA |  | x |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 018 | Южная часть Африки | Лесото | 426 | LSO | x | x |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 018 | Южная часть Африки | Намибия | 516 | NAM |  |  |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 018 | Южная часть Африки | Южная Африка | 710 | ZAF |  |  |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 018 | Южная часть Африки | Свазиленд | 748 | SWZ |  | x |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 011 | Западная Африка | Бенин | 204 | BEN | x |  |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 011 | Западная Африка | Буркина-Фасо | 854 | BFA | x | x |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 011 | Западная Африка | Кабо-Верде | 132 | CPV |  |  | x | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 011 | Западная Африка | Кот-д'Ивуар | 384 | CIV |  |  |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 011 | Западная Африка | Гамбия | 270 | GMB | x |  |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 011 | Западная Африка | Гана | 288 | GHA |  |  |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 011 | Западная Африка | Гвинея | 324 | GIN | x |  |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 011 | Западная Африка | Гвинея-Бисау | 624 | GNB | x |  | x | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 011 | Западная Африка | Либерия | 430 | LBR | x |  |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 011 | Западная Африка | Мали | 466 | MLI | x | x |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 011 | Западная Африка | Мавритания | 478 | MRT | x |  |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 011 | Западная Африка | Нигер | 562 | NER | x | x |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 011 | Западная Африка | Нигерия | 566 | NGA |  |  |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 011 | Западная Африка | Остров Святой Елены | 654 | SHN |  |  |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 011 | Западная Африка | Сенегал | 686 | SEN | x |  |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 011 | Западная Африка | Сьерра-Леоне | 694 | SLE | x |  |  | `Developing`
001 | Весь мир | 002 | Африка | 202 | страны Африки к югу от Сахары | 011 | Западная Африка | Того | 768 | TGO | x |  |  | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 029 | Карибский бассейн | Ангилья | 660 | AIA |  |  | x | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 029 | Карибский бассейн | Антигуа и Барбуда | 028 | ATG |  |  | x | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 029 | Карибский бассейн | Аруба | 533 | ABW |  |  | x | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 029 | Карибский бассейн | Багамские Острова | 044 | BHS |  |  | x | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 029 | Карибский бассейн | Барбадос | 052 | BRB |  |  | x | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 029 | Карибский бассейн | Бонайре, Саба и Синт-Эстатиус | 535 | BES |  |  | x | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 029 | Карибский бассейн | Британские Виргинские острова | 092 | VGB |  |  | x | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 029 | Карибский бассейн | Кайман острова | 136 | CYM |  |  |  | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 029 | Карибский бассейн | Куба | 192 | CUB |  |  | x | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 029 | Карибский бассейн | Кюрасао | 531 | CUW |  |  | x | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 029 | Карибский бассейн | Доминика | 212 | DMA |  |  | x | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 029 | Карибский бассейн | Доминиканская Республика | 214 | DOM |  |  | x | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 029 | Карибский бассейн | Гренада | 308 | GRD |  |  | x | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 029 | Карибский бассейн | Гваделупа | 312 | GLP |  |  |  | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 029 | Карибский бассейн | Гаити | 332 | HTI | x |  | x | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 029 | Карибский бассейн | Ямайка | 388 | JAM |  |  | x | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 029 | Карибский бассейн | Мартиника | 474 | MTQ |  |  |  | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 029 | Карибский бассейн | Монтсеррат | 500 | MSR |  |  | x | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 029 | Карибский бассейн | Пуэрто-Рико | 630 | PRI |  |  | x | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 029 | Карибский бассейн | Святой Варфоломей | 652 | BLM |  |  |  | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 029 | Карибский бассейн | Сент-Китс и Невис | 659 | KNA |  |  | x | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 029 | Карибский бассейн | Сент-Люсия | 662 | LCA |  |  | x | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 029 | Карибский бассейн | Сен-Мартен | 663 | MAF |  |  |  | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 029 | Карибский бассейн | Сент-Винсент и Гренадины | 670 | VCT |  |  | x | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 029 | Карибский бассейн | Синт-Мартен | 534 | SXM |  |  | x | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 029 | Карибский бассейн | Тринидад и Тобаго | 780 | TTO |  |  | x | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 029 | Карибский бассейн | Острова Тёркс и Кайкос | 796 | TCA |  |  |  | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 029 | Карибский бассейн | Виргинские oстрова Coeдинeнныx Штaтoв | 850 | VIR |  |  | x | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 013 | Центральная Америка | Белиз | 084 | BLZ |  |  | x | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 013 | Центральная Америка | Коста-Рика | 188 | CRI |  |  |  | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 013 | Центральная Америка | Сальвадор | 222 | SLV |  |  |  | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 013 | Центральная Америка | Гватемала | 320 | GTM |  |  |  | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 013 | Центральная Америка | Гондурас | 340 | HND |  |  |  | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 013 | Центральная Америка | Мексика | 484 | MEX |  |  |  | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 013 | Центральная Америка | Никарагуа | 558 | NIC |  |  |  | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 013 | Центральная Америка | Панама | 591 | PAN |  |  |  | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 005 | Южная Америка | Аргентина | 032 | ARG |  |  |  | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 005 | Южная Америка | Боливия (Многонациональное Государство) | 068 | BOL |  | x |  | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 005 | Южная Америка | Остров Буве | 074 | BVT |  |  |  | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 005 | Южная Америка | Бразилия | 076 | BRA |  |  |  | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 005 | Южная Америка | Чили | 152 | CHL |  |  |  | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 005 | Южная Америка | Колумбия | 170 | COL |  |  |  | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 005 | Южная Америка | Эквадор | 218 | ECU |  |  |  | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 005 | Южная Америка | Фолклендские (Мальвинские) острова | 238 | FLK |  |  |  | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 005 | Южная Америка | Французская Гвиана | 254 | GUF |  |  |  | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 005 | Южная Америка | Гайана | 328 | GUY |  |  | x | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 005 | Южная Америка | Парагвай | 600 | PRY |  | x |  | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 005 | Южная Америка | Перу | 604 | PER |  |  |  | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 005 | Южная Америка | Южная Джорджия и Южные Сандвичевы острова | 239 | SGS |  |  |  | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 005 | Южная Америка | Суринам | 740 | SUR |  |  | x | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 005 | Южная Америка | Уругвай | 858 | URY |  |  |  | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 419 | Латинская Америка и Карибский бассейн | 005 | Южная Америка | Венесуэла (Боливарианская Республика) | 862 | VEN |  |  |  | `Developing`
001 | Весь мир | 019 | Северная и Южная Америка | 021 | Северная Америка |  |  | Бермудские острова | 060 | BMU |  |  |  | `Developed`
001 | Весь мир | 019 | Северная и Южная Америка | 021 | Северная Америка |  |  | Канада | 124 | CAN |  |  |  | `Developed`
001 | Весь мир | 019 | Северная и Южная Америка | 021 | Северная Америка |  |  | Гренландия | 304 | GRL |  |  |  | `Developed`
001 | Весь мир | 019 | Северная и Южная Америка | 021 | Северная Америка |  |  | Сен-Пьер и Микелон | 666 | SPM |  |  |  | `Developed`
001 | Весь мир | 019 | Северная и Южная Америка | 021 | Северная Америка |  |  | Соединенные Штаты Америки | 840 | USA |  |  |  | `Developed`
001 | Весь мир |  |  |  |  |  |  | Антарктике | 010 | ATA |  |  |  |
001 | Весь мир | 142 | Азия | 143 | Центральная Азия |  |  | Казахстан | 398 | KAZ |  | x |  | `Developing`
001 | Весь мир | 142 | Азия | 143 | Центральная Азия |  |  | Кыргызстан | 417 | KGZ |  | x |  | `Developing`
001 | Весь мир | 142 | Азия | 143 | Центральная Азия |  |  | Таджикистан | 762 | TJK |  | x |  | `Developing`
001 | Весь мир | 142 | Азия | 143 | Центральная Азия |  |  | Туркменистан | 795 | TKM |  | x |  | `Developing`
001 | Весь мир | 142 | Азия | 143 | Центральная Азия |  |  | Узбекистан | 860 | UZB |  | x |  | `Developing`
001 | Весь мир | 142 | Азия | 030 | Восточная Азия |  |  | Китай | 156 | CHN |  |  |  | `Developing`
001 | Весь мир | 142 | Азия | 030 | Восточная Азия |  |  | Китай, Специальный административный район Гонконг | 344 | HKG |  |  |  | `Developing`
001 | Весь мир | 142 | Азия | 030 | Восточная Азия |  |  | Китай, Специальный административный район Макао | 446 | MAC |  |  |  | `Developing`
001 | Весь мир | 142 | Азия | 030 | Восточная Азия |  |  | Корейская Народно-Демократическая Республика | 408 | PRK |  |  |  | `Developing`
001 | Весь мир | 142 | Азия | 030 | Восточная Азия |  |  | Япония | 392 | JPN |  |  |  | `Developed`
001 | Весь мир | 142 | Азия | 030 | Восточная Азия |  |  | Монголия | 496 | MNG |  | x |  | `Developing`
001 | Весь мир | 142 | Азия | 030 | Восточная Азия |  |  | Республика Корея | 410 | KOR |  |  |  | `Developing`
001 | Весь мир | 142 | Азия | 035 | Юго-Восточная Азия |  |  | Бруней-Даруссалам | 096 | BRN |  |  |  | `Developing`
001 | Весь мир | 142 | Азия | 035 | Юго-Восточная Азия |  |  | Камбоджа | 116 | KHM | x |  |  | `Developing`
001 | Весь мир | 142 | Азия | 035 | Юго-Восточная Азия |  |  | Индонезия | 360 | IDN |  |  |  | `Developing`
001 | Весь мир | 142 | Азия | 035 | Юго-Восточная Азия |  |  | Лаосская Народно-Демократическая Республика | 418 | LAO | x | x |  | `Developing`
001 | Весь мир | 142 | Азия | 035 | Юго-Восточная Азия |  |  | Малайзия | 458 | MYS |  |  |  | `Developing`
001 | Весь мир | 142 | Азия | 035 | Юго-Восточная Азия |  |  | Мьянма | 104 | MMR | x |  |  | `Developing`
001 | Весь мир | 142 | Азия | 035 | Юго-Восточная Азия |  |  | Филиппины | 608 | PHL |  |  |  | `Developing`
001 | Весь мир | 142 | Азия | 035 | Юго-Восточная Азия |  |  | Сингапур | 702 | SGP |  |  | x | `Developing`
001 | Весь мир | 142 | Азия | 035 | Юго-Восточная Азия |  |  | Таиланд | 764 | THA |  |  |  | `Developing`
001 | Весь мир | 142 | Азия | 035 | Юго-Восточная Азия |  |  | Тимор-Лешти | 626 | TLS | x |  | x | `Developing`
001 | Весь мир | 142 | Азия | 035 | Юго-Восточная Азия |  |  | Вьетнам | 704 | VNM |  |  |  | `Developing`
001 | Весь мир | 142 | Азия | 034 | Южная Азия |  |  | Афганистан | 004 | AFG | x | x |  | `Developing`
001 | Весь мир | 142 | Азия | 034 | Южная Азия |  |  | Бангладеш | 050 | BGD | x |  |  | `Developing`
001 | Весь мир | 142 | Азия | 034 | Южная Азия |  |  | Бутан | 064 | BTN | x | x |  | `Developing`
001 | Весь мир | 142 | Азия | 034 | Южная Азия |  |  | Индия | 356 | IND |  |  |  | `Developing`
001 | Весь мир | 142 | Азия | 034 | Южная Азия |  |  | Иран (Исламская Республика) | 364 | IRN |  |  |  | `Developing`
001 | Весь мир | 142 | Азия | 034 | Южная Азия |  |  | Мальдивские Острова | 462 | MDV |  |  | x | `Developing`
001 | Весь мир | 142 | Азия | 034 | Южная Азия |  |  | Непал | 524 | NPL | x | x |  | `Developing`
001 | Весь мир | 142 | Азия | 034 | Южная Азия |  |  | Пакистан | 586 | PAK |  |  |  | `Developing`
001 | Весь мир | 142 | Азия | 034 | Южная Азия |  |  | Шри-Ланка | 144 | LKA |  |  |  | `Developing`
001 | Весь мир | 142 | Азия | 145 | Западная Азия |  |  | Армения | 051 | ARM |  | x |  | `Developing`
001 | Весь мир | 142 | Азия | 145 | Западная Азия |  |  | Азербайджан | 031 | AZE |  | x |  | `Developing`
001 | Весь мир | 142 | Азия | 145 | Западная Азия |  |  | Бахрейн | 048 | BHR |  |  |  | `Developing`
001 | Весь мир | 142 | Азия | 145 | Западная Азия |  |  | Кипр | 196 | CYP |  |  |  | `Developing`
001 | Весь мир | 142 | Азия | 145 | Западная Азия |  |  | Грузия | 268 | GEO |  |  |  | `Developing`
001 | Весь мир | 142 | Азия | 145 | Западная Азия |  |  | Ирак | 368 | IRQ |  |  |  | `Developing`
001 | Весь мир | 142 | Азия | 145 | Западная Азия |  |  | Израиль | 376 | ISR |  |  |  | `Developing`
001 | Весь мир | 142 | Азия | 145 | Западная Азия |  |  | Иордания | 400 | JOR |  |  |  | `Developing`
001 | Весь мир | 142 | Азия | 145 | Западная Азия |  |  | Кувейт | 414 | KWT |  |  |  | `Developing`
001 | Весь мир | 142 | Азия | 145 | Западная Азия |  |  | Ливан | 422 | LBN |  |  |  | `Developing`
001 | Весь мир | 142 | Азия | 145 | Западная Азия |  |  | Оман | 512 | OMN |  |  |  | `Developing`
001 | Весь мир | 142 | Азия | 145 | Западная Азия |  |  | Катар | 634 | QAT |  |  |  | `Developing`
001 | Весь мир | 142 | Азия | 145 | Западная Азия |  |  | Саудовская Аравия | 682 | SAU |  |  |  | `Developing`
001 | Весь мир | 142 | Азия | 145 | Западная Азия |  |  | Государство Палестина | 275 | PSE |  |  |  | `Developing`
001 | Весь мир | 142 | Азия | 145 | Западная Азия |  |  | Сирийская Арабская Республика | 760 | SYR |  |  |  | `Developing`
001 | Весь мир | 142 | Азия | 145 | Западная Азия |  |  | Турция | 792 | TUR |  |  |  | `Developing`
001 | Весь мир | 142 | Азия | 145 | Западная Азия |  |  | Объединенные Арабские Эмираты | 784 | ARE |  |  |  | `Developing`
001 | Весь мир | 142 | Азия | 145 | Западная Азия |  |  | Йемен | 887 | YEM | x |  |  | `Developing`
001 | Весь мир | 150 | Европа | 151 | Восточная Европа |  |  | Беларусь | 112 | BLR |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 151 | Восточная Европа |  |  | Болгария | 100 | BGR |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 151 | Восточная Европа |  |  | Чехия | 203 | CZE |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 151 | Восточная Европа |  |  | Венгрия | 348 | HUN |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 151 | Восточная Европа |  |  | Польша | 616 | POL |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 151 | Восточная Европа |  |  | Республика Молдова | 498 | MDA |  | x |  | `Developed`
001 | Весь мир | 150 | Европа | 151 | Восточная Европа |  |  | Румыния | 642 | ROU |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 151 | Восточная Европа |  |  | Российская Федерация | 643 | RUS |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 151 | Восточная Европа |  |  | Словакия | 703 | SVK |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 151 | Восточная Европа |  |  | Украина | 804 | UKR |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 154 | Северная Европа |  |  | Аландские острова | 248 | ALA |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 154 | Северная Европа | 830 | Нормандские острова | Гернси | 831 | GGY |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 154 | Северная Европа | 830 | Нормандские острова | Джерси | 832 | JEY |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 154 | Северная Европа | 830 | Нормандские острова | Сарк | 680 |  |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 154 | Северная Европа |  |  | Дания | 208 | DNK |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 154 | Северная Европа |  |  | Эстония | 233 | EST |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 154 | Северная Европа |  |  | Фарерские острова | 234 | FRO |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 154 | Северная Европа |  |  | Финляндия | 246 | FIN |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 154 | Северная Европа |  |  | Исландия | 352 | ISL |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 154 | Северная Европа |  |  | Ирландия | 372 | IRL |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 154 | Северная Европа |  |  | Остров Мэн | 833 | IMN |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 154 | Северная Европа |  |  | Латвия | 428 | LVA |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 154 | Северная Европа |  |  | Литва | 440 | LTU |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 154 | Северная Европа |  |  | Норвегия | 578 | NOR |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 154 | Северная Европа |  |  | Острова Свальбард и Ян-Майен | 744 | SJM |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 154 | Северная Европа |  |  | Швеция | 752 | SWE |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 154 | Северная Европа |  |  | Соединенное Королевство Великобритании и Северной Ирландии | 826 | GBR |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 039 | Южная Европа |  |  | Албания | 008 | ALB |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 039 | Южная Европа |  |  | Андорра | 020 | AND |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 039 | Южная Европа |  |  | Босния и Герцеговина | 070 | BIH |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 039 | Южная Европа |  |  | Хорватия | 191 | HRV |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 039 | Южная Европа |  |  | Гибралтар | 292 | GIB |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 039 | Южная Европа |  |  | Греция | 300 | GRC |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 039 | Южная Европа |  |  | Святой Престол | 336 | VAT |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 039 | Южная Европа |  |  | Италия | 380 | ITA |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 039 | Южная Европа |  |  | Мальта | 470 | MLT |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 039 | Южная Европа |  |  | Черногория | 499 | MNE |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 039 | Южная Европа |  |  | Португалия | 620 | PRT |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 039 | Южная Европа |  |  | Сан-Марино | 674 | SMR |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 039 | Южная Европа |  |  | Сербия | 688 | SRB |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 039 | Южная Европа |  |  | Словения | 705 | SVN |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 039 | Южная Европа |  |  | Испания | 724 | ESP |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 039 | Южная Европа |  |  | бывшая югославская Республика Македония | 807 | MKD |  | x |  | `Developed`
001 | Весь мир | 150 | Европа | 155 | Западная Европа |  |  | Австрия | 040 | AUT |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 155 | Западная Европа |  |  | Бельгия | 056 | BEL |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 155 | Западная Европа |  |  | Франция | 250 | FRA |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 155 | Западная Европа |  |  | Германия | 276 | DEU |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 155 | Западная Европа |  |  | Лихтенштейн | 438 | LIE |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 155 | Западная Европа |  |  | Люксембург | 442 | LUX |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 155 | Западная Европа |  |  | Монако | 492 | MCO |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 155 | Западная Европа |  |  | Нидерланды | 528 | NLD |  |  |  | `Developed`
001 | Весь мир | 150 | Европа | 155 | Западная Европа |  |  | Швейцария | 756 | CHE |  |  |  | `Developed`
001 | Весь мир | 009 | Океания | 053 | Австралия и Новая Зеландия |  |  | Австралия | 036 | AUS |  |  |  | `Developed`
001 | Весь мир | 009 | Океания | 053 | Австралия и Новая Зеландия |  |  | остров Рождества | 162 | CXR |  |  |  | `Developed`
001 | Весь мир | 009 | Океания | 053 | Австралия и Новая Зеландия |  |  | Кокосовых (Килинг) островов | 166 | CCK |  |  |  | `Developed`
001 | Весь мир | 009 | Океания | 053 | Австралия и Новая Зеландия |  |  | Остров Херд и острова Макдональд | 334 | HMD |  |  |  | `Developed`
001 | Весь мир | 009 | Океания | 053 | Австралия и Новая Зеландия |  |  | Новая Зеландия | 554 | NZL |  |  |  | `Developed`
001 | Весь мир | 009 | Океания | 053 | Австралия и Новая Зеландия |  |  | Остров Норфолк | 574 | NFK |  |  |  | `Developed`
001 | Весь мир | 009 | Океания | 054 | Меланезия |  |  | Фиджи | 242 | FJI |  |  | x | `Developing`
001 | Весь мир | 009 | Океания | 054 | Меланезия |  |  | Новая Каледония | 540 | NCL |  |  | x | `Developing`
001 | Весь мир | 009 | Океания | 054 | Меланезия |  |  | Папуа-Новая Гвинея | 598 | PNG |  |  | x | `Developing`
001 | Весь мир | 009 | Океания | 054 | Меланезия |  |  | Соломоновы Острова | 090 | SLB | x |  | x | `Developing`
001 | Весь мир | 009 | Океания | 054 | Меланезия |  |  | Вануату | 548 | VUT | x |  | x | `Developing`
001 | Весь мир | 009 | Океания | 057 | Микронезия |  |  | Гуам | 316 | GUM |  |  | x | `Developing`
001 | Весь мир | 009 | Океания | 057 | Микронезия |  |  | Кирибати | 296 | KIR | x |  | x | `Developing`
001 | Весь мир | 009 | Океания | 057 | Микронезия |  |  | Маршалловы Острова | 584 | MHL |  |  | x | `Developing`
001 | Весь мир | 009 | Океания | 057 | Микронезия |  |  | Микронезия (Федеративные Штаты) | 583 | FSM |  |  | x | `Developing`
001 | Весь мир | 009 | Океания | 057 | Микронезия |  |  | Науру | 520 | NRU |  |  | x | `Developing`
001 | Весь мир | 009 | Океания | 057 | Микронезия |  |  | Северные Марианские острова | 580 | MNP |  |  | x | `Developing`
001 | Весь мир | 009 | Океания | 057 | Микронезия |  |  | Палау | 585 | PLW |  |  | x | `Developing`
001 | Весь мир | 009 | Океания | 057 | Микронезия |  |  | Внешние малые острова Coeдинeнныx Штaтoв | 581 | UMI |  |  |  | `Developing`
001 | Весь мир | 009 | Океания | 061 | Полинезия |  |  | Американское Самоа | 016 | ASM |  |  | x | `Developing`
001 | Весь мир | 009 | Океания | 061 | Полинезия |  |  | Острова Кука | 184 | COK |  |  | x | `Developing`
001 | Весь мир | 009 | Океания | 061 | Полинезия |  |  | Французская Полинезия | 258 | PYF |  |  | x | `Developing`
001 | Весь мир | 009 | Океания | 061 | Полинезия |  |  | Ниуэ | 570 | NIU |  |  | x | `Developing`
001 | Весь мир | 009 | Океания | 061 | Полинезия |  |  | Питкэрн | 612 | PCN |  |  |  | `Developing`
001 | Весь мир | 009 | Океания | 061 | Полинезия |  |  | Самоа | 882 | WSM |  |  | x | `Developing`
001 | Весь мир | 009 | Океания | 061 | Полинезия |  |  | Токелау | 772 | TKL |  |  |  | `Developing`
001 | Весь мир | 009 | Океания | 061 | Полинезия |  |  | Тонга | 776 | TON |  |  | x | `Developing`
001 | Весь мир | 009 | Океания | 061 | Полинезия |  |  | Тувалу | 798 | TUV | x |  | x | `Developing`
001 | Весь мир | 009 | Океания | 061 | Полинезия |  |  | Острова Уоллис и Футуна | 876 | WLF |  |  |  | `Developing`

Global Code | Global Name | Region Code | Region Name | Sub-region Code | Sub-region Name | Intermediate Region Code | Intermediate Region Name | Country or Area | M49 Code | ISO-alpha3 Code | Least Developed Countries (LDC) | Land Locked Developing Countries (LLDC) | Small Island Developing States (SIDS) | Developed / Developing Countries
001 | Monde | 002 | Afrique | 015 | Afrique septentrionale |  |  | Algérie | 012 | DZA |  |  |  | `Developing`
001 | Monde | 002 | Afrique | 015 | Afrique septentrionale |  |  | Égypte | 818 | EGY |  |  |  | `Developing`
001 | Monde | 002 | Afrique | 015 | Afrique septentrionale |  |  | Libye | 434 | LBY |  |  |  | `Developing`
001 | Monde | 002 | Afrique | 015 | Afrique septentrionale |  |  | Maroc | 504 | MAR |  |  |  | `Developing`
001 | Monde | 002 | Afrique | 015 | Afrique septentrionale |  |  | Soudan | 729 | SDN | x |  |  | `Developing`
001 | Monde | 002 | Afrique | 015 | Afrique septentrionale |  |  | Tunisie | 788 | TUN |  |  |  | `Developing`
001 | Monde | 002 | Afrique | 015 | Afrique septentrionale |  |  | Sahara occidental | 732 | ESH |  |  |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 014 | Afrique orientale | Territoire britannique de l'océan Indien | 086 | IOT |  |  |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 014 | Afrique orientale | Burundi | 108 | BDI | x | x |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 014 | Afrique orientale | Comores | 174 | COM | x |  | x | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 014 | Afrique orientale | Djibouti | 262 | DJI | x |  |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 014 | Afrique orientale | Érythrée | 232 | ERI | x |  |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 014 | Afrique orientale | Éthiopie | 231 | ETH | x | x |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 014 | Afrique orientale | Terres australes françaises | 260 | ATF |  |  |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 014 | Afrique orientale | Kenya | 404 | KEN |  |  |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 014 | Afrique orientale | Madagascar | 450 | MDG | x |  |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 014 | Afrique orientale | Malawi | 454 | MWI | x | x |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 014 | Afrique orientale | Maurice | 480 | MUS |  |  | x | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 014 | Afrique orientale | Mayotte | 175 | MYT |  |  |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 014 | Afrique orientale | Mozambique | 508 | MOZ | x |  |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 014 | Afrique orientale | Réunion | 638 | REU |  |  |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 014 | Afrique orientale | Rwanda | 646 | RWA | x | x |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 014 | Afrique orientale | Seychelles | 690 | SYC |  |  | x | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 014 | Afrique orientale | Somalie | 706 | SOM | x |  |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 014 | Afrique orientale | Soudan du Sud | 728 | SSD | x | x |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 014 | Afrique orientale | Ouganda | 800 | UGA | x | x |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 014 | Afrique orientale | République-Unie de Tanzanie | 834 | TZA | x |  |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 014 | Afrique orientale | Zambie | 894 | ZMB | x | x |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 014 | Afrique orientale | Zimbabwe | 716 | ZWE |  | x |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 017 | Afrique centrale | Angola | 024 | AGO | x |  |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 017 | Afrique centrale | Cameroun | 120 | CMR |  |  |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 017 | Afrique centrale | République centrafricaine | 140 | CAF | x | x |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 017 | Afrique centrale | Tchad | 148 | TCD | x | x |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 017 | Afrique centrale | Congo | 178 | COG |  |  |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 017 | Afrique centrale | République démocratique du Congo | 180 | COD | x |  |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 017 | Afrique centrale | Guinée équatoriale | 226 | GNQ | x |  |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 017 | Afrique centrale | Gabon | 266 | GAB |  |  |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 017 | Afrique centrale | Sao Tomé-et-Principe | 678 | STP | x |  | x | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 018 | Afrique australe | Botswana | 072 | BWA |  | x |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 018 | Afrique australe | Lesotho | 426 | LSO | x | x |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 018 | Afrique australe | Namibie | 516 | NAM |  |  |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 018 | Afrique australe | Afrique du Sud | 710 | ZAF |  |  |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 018 | Afrique australe | Swaziland | 748 | SWZ |  | x |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 011 | Afrique occidentale | Bénin | 204 | BEN | x |  |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 011 | Afrique occidentale | Burkina Faso | 854 | BFA | x | x |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 011 | Afrique occidentale | Cabo Verde | 132 | CPV |  |  | x | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 011 | Afrique occidentale | Côte d'Ivoire | 384 | CIV |  |  |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 011 | Afrique occidentale | Gambie | 270 | GMB | x |  |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 011 | Afrique occidentale | Ghana | 288 | GHA |  |  |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 011 | Afrique occidentale | Guinée | 324 | GIN | x |  |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 011 | Afrique occidentale | Guinée-Bissau | 624 | GNB | x |  | x | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 011 | Afrique occidentale | Libéria | 430 | LBR | x |  |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 011 | Afrique occidentale | Mali | 466 | MLI | x | x |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 011 | Afrique occidentale | Mauritanie | 478 | MRT | x |  |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 011 | Afrique occidentale | Niger | 562 | NER | x | x |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 011 | Afrique occidentale | Nigéria | 566 | NGA |  |  |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 011 | Afrique occidentale | Sainte-Hélène | 654 | SHN |  |  |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 011 | Afrique occidentale | Sénégal | 686 | SEN | x |  |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 011 | Afrique occidentale | Sierra Leone | 694 | SLE | x |  |  | `Developing`
001 | Monde | 002 | Afrique | 202 | Afrique subsaharienne | 011 | Afrique occidentale | Togo | 768 | TGO | x |  |  | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 029 | Caraïbes | Anguilla | 660 | AIA |  |  | x | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 029 | Caraïbes | Antigua-et-Barbuda | 028 | ATG |  |  | x | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 029 | Caraïbes | Aruba | 533 | ABW |  |  | x | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 029 | Caraïbes | Bahamas | 044 | BHS |  |  | x | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 029 | Caraïbes | Barbade | 052 | BRB |  |  | x | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 029 | Caraïbes | Bonaire, Saint-Eustache et Saba | 535 | BES |  |  | x | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 029 | Caraïbes | Îles Vierges britanniques | 092 | VGB |  |  | x | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 029 | Caraïbes | Îles Caïmanes | 136 | CYM |  |  |  | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 029 | Caraïbes | Cuba | 192 | CUB |  |  | x | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 029 | Caraïbes | Curaçao | 531 | CUW |  |  | x | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 029 | Caraïbes | Dominique | 212 | DMA |  |  | x | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 029 | Caraïbes | République dominicaine | 214 | DOM |  |  | x | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 029 | Caraïbes | Grenade | 308 | GRD |  |  | x | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 029 | Caraïbes | Guadeloupe | 312 | GLP |  |  |  | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 029 | Caraïbes | Haïti | 332 | HTI | x |  | x | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 029 | Caraïbes | Jamaïque | 388 | JAM |  |  | x | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 029 | Caraïbes | Martinique | 474 | MTQ |  |  |  | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 029 | Caraïbes | Montserrat | 500 | MSR |  |  | x | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 029 | Caraïbes | Porto Rico | 630 | PRI |  |  | x | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 029 | Caraïbes | Saint-Barthélemy | 652 | BLM |  |  |  | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 029 | Caraïbes | Saint-Kitts-et-Nevis | 659 | KNA |  |  | x | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 029 | Caraïbes | Sainte-Lucie | 662 | LCA |  |  | x | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 029 | Caraïbes | Saint-Martin (partie française) | 663 | MAF |  |  |  | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 029 | Caraïbes | Saint-Vincent-et-les Grenadines | 670 | VCT |  |  | x | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 029 | Caraïbes | Saint-Martin (partie néerlandaise) | 534 | SXM |  |  | x | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 029 | Caraïbes | Trinité-et-Tobago | 780 | TTO |  |  | x | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 029 | Caraïbes | Îles Turques-et-Caïques | 796 | TCA |  |  |  | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 029 | Caraïbes | Îles Vierges américaines | 850 | VIR |  |  | x | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 013 | Amérique centrale | Belize | 084 | BLZ |  |  | x | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 013 | Amérique centrale | Costa Rica | 188 | CRI |  |  |  | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 013 | Amérique centrale | El Salvador | 222 | SLV |  |  |  | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 013 | Amérique centrale | Guatemala | 320 | GTM |  |  |  | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 013 | Amérique centrale | Honduras | 340 | HND |  |  |  | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 013 | Amérique centrale | Mexique | 484 | MEX |  |  |  | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 013 | Amérique centrale | Nicaragua | 558 | NIC |  |  |  | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 013 | Amérique centrale | Panama | 591 | PAN |  |  |  | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 005 | Amérique du Sud | Argentine | 032 | ARG |  |  |  | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 005 | Amérique du Sud | Bolivie (État plurinational de) | 068 | BOL |  | x |  | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 005 | Amérique du Sud | Île Bouvet | 074 | BVT |  |  |  | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 005 | Amérique du Sud | Brésil | 076 | BRA |  |  |  | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 005 | Amérique du Sud | Chili | 152 | CHL |  |  |  | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 005 | Amérique du Sud | Colombie | 170 | COL |  |  |  | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 005 | Amérique du Sud | Équateur | 218 | ECU |  |  |  | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 005 | Amérique du Sud | Îles Falkland (Malvinas) | 238 | FLK |  |  |  | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 005 | Amérique du Sud | Guyane française | 254 | GUF |  |  |  | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 005 | Amérique du Sud | Guyana | 328 | GUY |  |  | x | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 005 | Amérique du Sud | Paraguay | 600 | PRY |  | x |  | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 005 | Amérique du Sud | Pérou | 604 | PER |  |  |  | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 005 | Amérique du Sud | Géorgie du Sud-et-les Îles Sandwich du Sud | 239 | SGS |  |  |  | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 005 | Amérique du Sud | Suriname | 740 | SUR |  |  | x | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 005 | Amérique du Sud | Uruguay | 858 | URY |  |  |  | `Developing`
001 | Monde | 019 | Amériques | 419 | Amérique latine et Caraïbes | 005 | Amérique du Sud | Venezuela (République bolivarienne du) | 862 | VEN |  |  |  | `Developing`
001 | Monde | 019 | Amériques | 021 | Amérique septentrionale |  |  | Bermudes | 060 | BMU |  |  |  | `Developed`
001 | Monde | 019 | Amériques | 021 | Amérique septentrionale |  |  | Canada | 124 | CAN |  |  |  | `Developed`
001 | Monde | 019 | Amériques | 021 | Amérique septentrionale |  |  | Groenland | 304 | GRL |  |  |  | `Developed`
001 | Monde | 019 | Amériques | 021 | Amérique septentrionale |  |  | Saint-Pierre-et-Miquelon | 666 | SPM |  |  |  | `Developed`
001 | Monde | 019 | Amériques | 021 | Amérique septentrionale |  |  | États-Unis d'Amérique | 840 | USA |  |  |  | `Developed`
001 | Monde |  |  |  |  |  |  | Antarctique | 010 | ATA |  |  |  |
001 | Monde | 142 | Asie | 143 | Asie centrale |  |  | Kazakhstan | 398 | KAZ |  | x |  | `Developing`
001 | Monde | 142 | Asie | 143 | Asie centrale |  |  | Kirghizistan | 417 | KGZ |  | x |  | `Developing`
001 | Monde | 142 | Asie | 143 | Asie centrale |  |  | Tadjikistan | 762 | TJK |  | x |  | `Developing`
001 | Monde | 142 | Asie | 143 | Asie centrale |  |  | Turkménistan | 795 | TKM |  | x |  | `Developing`
001 | Monde | 142 | Asie | 143 | Asie centrale |  |  | Ouzbékistan | 860 | UZB |  | x |  | `Developing`
001 | Monde | 142 | Asie | 030 | Asie orientale |  |  | Chine | 156 | CHN |  |  |  | `Developing`
001 | Monde | 142 | Asie | 030 | Asie orientale |  |  | Chine, région administrative spéciale de Hong Kong | 344 | HKG |  |  |  | `Developing`
001 | Monde | 142 | Asie | 030 | Asie orientale |  |  | Chine, région administrative spéciale de Macao | 446 | MAC |  |  |  | `Developing`
001 | Monde | 142 | Asie | 030 | Asie orientale |  |  | République populaire démocratique de Corée | 408 | PRK |  |  |  | `Developing`
001 | Monde | 142 | Asie | 030 | Asie orientale |  |  | Japon | 392 | JPN |  |  |  | `Developed`
001 | Monde | 142 | Asie | 030 | Asie orientale |  |  | Mongolie | 496 | MNG |  | x |  | `Developing`
001 | Monde | 142 | Asie | 030 | Asie orientale |  |  | République de Corée | 410 | KOR |  |  |  | `Developing`
001 | Monde | 142 | Asie | 035 | Asie du Sud-Est |  |  | Brunéi Darussalam | 096 | BRN |  |  |  | `Developing`
001 | Monde | 142 | Asie | 035 | Asie du Sud-Est |  |  | Cambodge | 116 | KHM | x |  |  | `Developing`
001 | Monde | 142 | Asie | 035 | Asie du Sud-Est |  |  | Indonésie | 360 | IDN |  |  |  | `Developing`
001 | Monde | 142 | Asie | 035 | Asie du Sud-Est |  |  | République démocratique populaire lao | 418 | LAO | x | x |  | `Developing`
001 | Monde | 142 | Asie | 035 | Asie du Sud-Est |  |  | Malaisie | 458 | MYS |  |  |  | `Developing`
001 | Monde | 142 | Asie | 035 | Asie du Sud-Est |  |  | Myanmar | 104 | MMR | x |  |  | `Developing`
001 | Monde | 142 | Asie | 035 | Asie du Sud-Est |  |  | Philippines | 608 | PHL |  |  |  | `Developing`
001 | Monde | 142 | Asie | 035 | Asie du Sud-Est |  |  | Singapour | 702 | SGP |  |  | x | `Developing`
001 | Monde | 142 | Asie | 035 | Asie du Sud-Est |  |  | Thaïlande | 764 | THA |  |  |  | `Developing`
001 | Monde | 142 | Asie | 035 | Asie du Sud-Est |  |  | Timor-Leste | 626 | TLS | x |  | x | `Developing`
001 | Monde | 142 | Asie | 035 | Asie du Sud-Est |  |  | Viet Nam | 704 | VNM |  |  |  | `Developing`
001 | Monde | 142 | Asie | 034 | Asie méridionale |  |  | Afghanistan | 004 | AFG | x | x |  | `Developing`
001 | Monde | 142 | Asie | 034 | Asie méridionale |  |  | Bangladesh | 050 | BGD | x |  |  | `Developing`
001 | Monde | 142 | Asie | 034 | Asie méridionale |  |  | Bhoutan | 064 | BTN | x | x |  | `Developing`
001 | Monde | 142 | Asie | 034 | Asie méridionale |  |  | Inde | 356 | IND |  |  |  | `Developing`
001 | Monde | 142 | Asie | 034 | Asie méridionale |  |  | Iran (République islamique d') | 364 | IRN |  |  |  | `Developing`
001 | Monde | 142 | Asie | 034 | Asie méridionale |  |  | Maldives | 462 | MDV |  |  | x | `Developing`
001 | Monde | 142 | Asie | 034 | Asie méridionale |  |  | Népal | 524 | NPL | x | x |  | `Developing`
001 | Monde | 142 | Asie | 034 | Asie méridionale |  |  | Pakistan | 586 | PAK |  |  |  | `Developing`
001 | Monde | 142 | Asie | 034 | Asie méridionale |  |  | Sri Lanka | 144 | LKA |  |  |  | `Developing`
001 | Monde | 142 | Asie | 145 | Asie occidentale |  |  | Arménie | 051 | ARM |  | x |  | `Developing`
001 | Monde | 142 | Asie | 145 | Asie occidentale |  |  | Azerbaïdjan | 031 | AZE |  | x |  | `Developing`
001 | Monde | 142 | Asie | 145 | Asie occidentale |  |  | Bahreïn | 048 | BHR |  |  |  | `Developing`
001 | Monde | 142 | Asie | 145 | Asie occidentale |  |  | Chypre | 196 | CYP |  |  |  | `Developing`
001 | Monde | 142 | Asie | 145 | Asie occidentale |  |  | Géorgie | 268 | GEO |  |  |  | `Developing`
001 | Monde | 142 | Asie | 145 | Asie occidentale |  |  | Iraq | 368 | IRQ |  |  |  | `Developing`
001 | Monde | 142 | Asie | 145 | Asie occidentale |  |  | Israël | 376 | ISR |  |  |  | `Developing`
001 | Monde | 142 | Asie | 145 | Asie occidentale |  |  | Jordanie | 400 | JOR |  |  |  | `Developing`
001 | Monde | 142 | Asie | 145 | Asie occidentale |  |  | Koweït | 414 | KWT |  |  |  | `Developing`
001 | Monde | 142 | Asie | 145 | Asie occidentale |  |  | Liban | 422 | LBN |  |  |  | `Developing`
001 | Monde | 142 | Asie | 145 | Asie occidentale |  |  | Oman | 512 | OMN |  |  |  | `Developing`
001 | Monde | 142 | Asie | 145 | Asie occidentale |  |  | Qatar | 634 | QAT |  |  |  | `Developing`
001 | Monde | 142 | Asie | 145 | Asie occidentale |  |  | Arabie saoudite | 682 | SAU |  |  |  | `Developing`
001 | Monde | 142 | Asie | 145 | Asie occidentale |  |  | État de Palestine | 275 | PSE |  |  |  | `Developing`
001 | Monde | 142 | Asie | 145 | Asie occidentale |  |  | République arabe syrienne | 760 | SYR |  |  |  | `Developing`
001 | Monde | 142 | Asie | 145 | Asie occidentale |  |  | Turquie | 792 | TUR |  |  |  | `Developing`
001 | Monde | 142 | Asie | 145 | Asie occidentale |  |  | Émirats arabes unis | 784 | ARE |  |  |  | `Developing`
001 | Monde | 142 | Asie | 145 | Asie occidentale |  |  | Yémen | 887 | YEM | x |  |  | `Developing`
001 | Monde | 150 | Europe | 151 | Europe orientale |  |  | Bélarus | 112 | BLR |  |  |  | `Developed`
001 | Monde | 150 | Europe | 151 | Europe orientale |  |  | Bulgarie | 100 | BGR |  |  |  | `Developed`
001 | Monde | 150 | Europe | 151 | Europe orientale |  |  | Tchéquie | 203 | CZE |  |  |  | `Developed`
001 | Monde | 150 | Europe | 151 | Europe orientale |  |  | Hongrie | 348 | HUN |  |  |  | `Developed`
001 | Monde | 150 | Europe | 151 | Europe orientale |  |  | Pologne | 616 | POL |  |  |  | `Developed`
001 | Monde | 150 | Europe | 151 | Europe orientale |  |  | République de Moldova | 498 | MDA |  | x |  | `Developed`
001 | Monde | 150 | Europe | 151 | Europe orientale |  |  | Roumanie | 642 | ROU |  |  |  | `Developed`
001 | Monde | 150 | Europe | 151 | Europe orientale |  |  | Fédération de Russie | 643 | RUS |  |  |  | `Developed`
001 | Monde | 150 | Europe | 151 | Europe orientale |  |  | Slovaquie | 703 | SVK |  |  |  | `Developed`
001 | Monde | 150 | Europe | 151 | Europe orientale |  |  | Ukraine | 804 | UKR |  |  |  | `Developed`
001 | Monde | 150 | Europe | 154 | Europe septentrionale |  |  | Îles d'Åland | 248 | ALA |  |  |  | `Developed`
001 | Monde | 150 | Europe | 154 | Europe septentrionale | 830 | Îles Anglo-Normandes | Guernesey | 831 | GGY |  |  |  | `Developed`
001 | Monde | 150 | Europe | 154 | Europe septentrionale | 830 | Îles Anglo-Normandes | Jersey | 832 | JEY |  |  |  | `Developed`
001 | Monde | 150 | Europe | 154 | Europe septentrionale | 830 | Îles Anglo-Normandes | Sercq | 680 |  |  |  |  | `Developed`
001 | Monde | 150 | Europe | 154 | Europe septentrionale |  |  | Danemark | 208 | DNK |  |  |  | `Developed`
001 | Monde | 150 | Europe | 154 | Europe septentrionale |  |  | Estonie | 233 | EST |  |  |  | `Developed`
001 | Monde | 150 | Europe | 154 | Europe septentrionale |  |  | Îles Féroé | 234 | FRO |  |  |  | `Developed`
001 | Monde | 150 | Europe | 154 | Europe septentrionale |  |  | Finlande | 246 | FIN |  |  |  | `Developed`
001 | Monde | 150 | Europe | 154 | Europe septentrionale |  |  | Islande | 352 | ISL |  |  |  | `Developed`
001 | Monde | 150 | Europe | 154 | Europe septentrionale |  |  | Irlande | 372 | IRL |  |  |  | `Developed`
001 | Monde | 150 | Europe | 154 | Europe septentrionale |  |  | Île de Man | 833 | IMN |  |  |  | `Developed`
001 | Monde | 150 | Europe | 154 | Europe septentrionale |  |  | Lettonie | 428 | LVA |  |  |  | `Developed`
001 | Monde | 150 | Europe | 154 | Europe septentrionale |  |  | Lituanie | 440 | LTU |  |  |  | `Developed`
001 | Monde | 150 | Europe | 154 | Europe septentrionale |  |  | Norvège | 578 | NOR |  |  |  | `Developed`
001 | Monde | 150 | Europe | 154 | Europe septentrionale |  |  | Îles Svalbard-et-Jan Mayen | 744 | SJM |  |  |  | `Developed`
001 | Monde | 150 | Europe | 154 | Europe septentrionale |  |  | Suède | 752 | SWE |  |  |  | `Developed`
001 | Monde | 150 | Europe | 154 | Europe septentrionale |  |  | Royaume-Uni de Grande-Bretagne et d'Irlande du Nord | 826 | GBR |  |  |  | `Developed`
001 | Monde | 150 | Europe | 039 | Europe méridionale |  |  | Albanie | 008 | ALB |  |  |  | `Developed`
001 | Monde | 150 | Europe | 039 | Europe méridionale |  |  | Andorre | 020 | AND |  |  |  | `Developed`
001 | Monde | 150 | Europe | 039 | Europe méridionale |  |  | Bosnie-Herzégovine | 070 | BIH |  |  |  | `Developed`
001 | Monde | 150 | Europe | 039 | Europe méridionale |  |  | Croatie | 191 | HRV |  |  |  | `Developed`
001 | Monde | 150 | Europe | 039 | Europe méridionale |  |  | Gibraltar | 292 | GIB |  |  |  | `Developed`
001 | Monde | 150 | Europe | 039 | Europe méridionale |  |  | Grèce | 300 | GRC |  |  |  | `Developed`
001 | Monde | 150 | Europe | 039 | Europe méridionale |  |  | Saint-Siège | 336 | VAT |  |  |  | `Developed`
001 | Monde | 150 | Europe | 039 | Europe méridionale |  |  | Italie | 380 | ITA |  |  |  | `Developed`
001 | Monde | 150 | Europe | 039 | Europe méridionale |  |  | Malte | 470 | MLT |  |  |  | `Developed`
001 | Monde | 150 | Europe | 039 | Europe méridionale |  |  | Monténégro | 499 | MNE |  |  |  | `Developed`
001 | Monde | 150 | Europe | 039 | Europe méridionale |  |  | Portugal | 620 | PRT |  |  |  | `Developed`
001 | Monde | 150 | Europe | 039 | Europe méridionale |  |  | Saint-Marin | 674 | SMR |  |  |  | `Developed`
001 | Monde | 150 | Europe | 039 | Europe méridionale |  |  | Serbie | 688 | SRB |  |  |  | `Developed`
001 | Monde | 150 | Europe | 039 | Europe méridionale |  |  | Slovénie | 705 | SVN |  |  |  | `Developed`
001 | Monde | 150 | Europe | 039 | Europe méridionale |  |  | Espagne | 724 | ESP |  |  |  | `Developed`
001 | Monde | 150 | Europe | 039 | Europe méridionale |  |  | ex-République yougoslave de Macédoine | 807 | MKD |  | x |  | `Developed`
001 | Monde | 150 | Europe | 155 | Europe occidentale |  |  | Autriche | 040 | AUT |  |  |  | `Developed`
001 | Monde | 150 | Europe | 155 | Europe occidentale |  |  | Belgique | 056 | BEL |  |  |  | `Developed`
001 | Monde | 150 | Europe | 155 | Europe occidentale |  |  | France | 250 | FRA |  |  |  | `Developed`
001 | Monde | 150 | Europe | 155 | Europe occidentale |  |  | Allemagne | 276 | DEU |  |  |  | `Developed`
001 | Monde | 150 | Europe | 155 | Europe occidentale |  |  | Liechtenstein | 438 | LIE |  |  |  | `Developed`
001 | Monde | 150 | Europe | 155 | Europe occidentale |  |  | Luxembourg | 442 | LUX |  |  |  | `Developed`
001 | Monde | 150 | Europe | 155 | Europe occidentale |  |  | Monaco | 492 | MCO |  |  |  | `Developed`
001 | Monde | 150 | Europe | 155 | Europe occidentale |  |  | Pays-Bas | 528 | NLD |  |  |  | `Developed`
001 | Monde | 150 | Europe | 155 | Europe occidentale |  |  | Suisse | 756 | CHE |  |  |  | `Developed`
001 | Monde | 009 | Océanie | 053 | Australie et Nouvelle-Zélande |  |  | Australie | 036 | AUS |  |  |  | `Developed`
001 | Monde | 009 | Océanie | 053 | Australie et Nouvelle-Zélande |  |  | Île Christmas | 162 | CXR |  |  |  | `Developed`
001 | Monde | 009 | Océanie | 053 | Australie et Nouvelle-Zélande |  |  | Îles des Cocos (Keeling) | 166 | CCK |  |  |  | `Developed`
001 | Monde | 009 | Océanie | 053 | Australie et Nouvelle-Zélande |  |  | Île Heard-et-Îles MacDonald | 334 | HMD |  |  |  | `Developed`
001 | Monde | 009 | Océanie | 053 | Australie et Nouvelle-Zélande |  |  | Nouvelle-Zélande | 554 | NZL |  |  |  | `Developed`
001 | Monde | 009 | Océanie | 053 | Australie et Nouvelle-Zélande |  |  | Île Norfolk | 574 | NFK |  |  |  | `Developed`
001 | Monde | 009 | Océanie | 054 | Mélanésie |  |  | Fidji | 242 | FJI |  |  | x | `Developing`
001 | Monde | 009 | Océanie | 054 | Mélanésie |  |  | Nouvelle-Calédonie | 540 | NCL |  |  | x | `Developing`
001 | Monde | 009 | Océanie | 054 | Mélanésie |  |  | Papouasie-Nouvelle-Guinée | 598 | PNG |  |  | x | `Developing`
001 | Monde | 009 | Océanie | 054 | Mélanésie |  |  | Îles Salomon | 090 | SLB | x |  | x | `Developing`
001 | Monde | 009 | Océanie | 054 | Mélanésie |  |  | Vanuatu | 548 | VUT | x |  | x | `Developing`
001 | Monde | 009 | Océanie | 057 | Micronésie |  |  | Guam | 316 | GUM |  |  | x | `Developing`
001 | Monde | 009 | Océanie | 057 | Micronésie |  |  | Kiribati | 296 | KIR | x |  | x | `Developing`
001 | Monde | 009 | Océanie | 057 | Micronésie |  |  | Îles Marshall | 584 | MHL |  |  | x | `Developing`
001 | Monde | 009 | Océanie | 057 | Micronésie |  |  | Micronésie (États fédérés de) | 583 | FSM |  |  | x | `Developing`
001 | Monde | 009 | Océanie | 057 | Micronésie |  |  | Nauru | 520 | NRU |  |  | x | `Developing`
001 | Monde | 009 | Océanie | 057 | Micronésie |  |  | Îles Mariannes du Nord | 580 | MNP |  |  | x | `Developing`
001 | Monde | 009 | Océanie | 057 | Micronésie |  |  | Palaos | 585 | PLW |  |  | x | `Developing`
001 | Monde | 009 | Océanie | 057 | Micronésie |  |  | Îles mineures éloignées des États-Unis | 581 | UMI |  |  |  | `Developing`
001 | Monde | 009 | Océanie | 061 | Polynésie |  |  | Samoa américaines | 016 | ASM |  |  | x | `Developing`
001 | Monde | 009 | Océanie | 061 | Polynésie |  |  | Îles Cook | 184 | COK |  |  | x | `Developing`
001 | Monde | 009 | Océanie | 061 | Polynésie |  |  | Polynésie française | 258 | PYF |  |  | x | `Developing`
001 | Monde | 009 | Océanie | 061 | Polynésie |  |  | Nioué | 570 | NIU |  |  | x | `Developing`
001 | Monde | 009 | Océanie | 061 | Polynésie |  |  | Pitcairn | 612 | PCN |  |  |  | `Developing`
001 | Monde | 009 | Océanie | 061 | Polynésie |  |  | Samoa | 882 | WSM |  |  | x | `Developing`
001 | Monde | 009 | Océanie | 061 | Polynésie |  |  | Tokélaou | 772 | TKL |  |  |  | `Developing`
001 | Monde | 009 | Océanie | 061 | Polynésie |  |  | Tonga | 776 | TON |  |  | x | `Developing`
001 | Monde | 009 | Océanie | 061 | Polynésie |  |  | Tuvalu | 798 | TUV | x |  | x | `Developing`
001 | Monde | 009 | Océanie | 061 | Polynésie |  |  | Îles Wallis-et-Futuna | 876 | WLF |  |  |  | `Developing`

Global Code | Global Name | Region Code | Region Name | Sub-region Code | Sub-region Name | Intermediate Region Code | Intermediate Region Name | Country or Area | M49 Code | ISO-alpha3 Code | Least Developed Countries (LDC) | Land Locked Developing Countries (LLDC) | Small Island Developing States (SIDS) | Developed / Developing Countries
001 | Mundo | 002 | África | 015 | África septentrional |  |  | Argelia | 012 | DZA |  |  |  | `Developing`
001 | Mundo | 002 | África | 015 | África septentrional |  |  | Egipto | 818 | EGY |  |  |  | `Developing`
001 | Mundo | 002 | África | 015 | África septentrional |  |  | Libia | 434 | LBY |  |  |  | `Developing`
001 | Mundo | 002 | África | 015 | África septentrional |  |  | Marruecos | 504 | MAR |  |  |  | `Developing`
001 | Mundo | 002 | África | 015 | África septentrional |  |  | Sudán | 729 | SDN | x |  |  | `Developing`
001 | Mundo | 002 | África | 015 | África septentrional |  |  | Túnez | 788 | TUN |  |  |  | `Developing`
001 | Mundo | 002 | África | 015 | África septentrional |  |  | Sáhara Occidental | 732 | ESH |  |  |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 014 | África oriental | Territorio Británico del Océano Índico | 086 | IOT |  |  |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 014 | África oriental | Burundi | 108 | BDI | x | x |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 014 | África oriental | Comoras | 174 | COM | x |  | x | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 014 | África oriental | Djibouti | 262 | DJI | x |  |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 014 | África oriental | Eritrea | 232 | ERI | x |  |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 014 | África oriental | Etiopía | 231 | ETH | x | x |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 014 | África oriental | Territorio de las Tierras Australes Francesas | 260 | ATF |  |  |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 014 | África oriental | Kenya | 404 | KEN |  |  |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 014 | África oriental | Madagascar | 450 | MDG | x |  |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 014 | África oriental | Malawi | 454 | MWI | x | x |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 014 | África oriental | Mauricio | 480 | MUS |  |  | x | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 014 | África oriental | Mayotte | 175 | MYT |  |  |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 014 | África oriental | Mozambique | 508 | MOZ | x |  |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 014 | África oriental | Reunión | 638 | REU |  |  |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 014 | África oriental | Rwanda | 646 | RWA | x | x |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 014 | África oriental | Seychelles | 690 | SYC |  |  | x | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 014 | África oriental | Somalia | 706 | SOM | x |  |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 014 | África oriental | Sudán del Sur | 728 | SSD | x | x |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 014 | África oriental | Uganda | 800 | UGA | x | x |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 014 | África oriental | República Unida de Tanzanía | 834 | TZA | x |  |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 014 | África oriental | Zambia | 894 | ZMB | x | x |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 014 | África oriental | Zimbabwe | 716 | ZWE |  | x |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 017 | África central | Angola | 024 | AGO | x |  |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 017 | África central | Camerún | 120 | CMR |  |  |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 017 | África central | República Centroafricana | 140 | CAF | x | x |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 017 | África central | Chad | 148 | TCD | x | x |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 017 | África central | Congo | 178 | COG |  |  |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 017 | África central | República Democrática del Congo | 180 | COD | x |  |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 017 | África central | Guinea Ecuatorial | 226 | GNQ | x |  |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 017 | África central | Gabón | 266 | GAB |  |  |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 017 | África central | Santo Tomé y Príncipe | 678 | STP | x |  | x | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 018 | África meridional | Botswana | 072 | BWA |  | x |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 018 | África meridional | Lesotho | 426 | LSO | x | x |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 018 | África meridional | Namibia | 516 | NAM |  |  |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 018 | África meridional | Sudáfrica | 710 | ZAF |  |  |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 018 | África meridional | Swazilandia | 748 | SWZ |  | x |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 011 | África occidental | Benin | 204 | BEN | x |  |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 011 | África occidental | Burkina Faso | 854 | BFA | x | x |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 011 | África occidental | Cabo Verde | 132 | CPV |  |  | x | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 011 | África occidental | Côte d'Ivoire | 384 | CIV |  |  |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 011 | África occidental | Gambia | 270 | GMB | x |  |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 011 | África occidental | Ghana | 288 | GHA |  |  |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 011 | África occidental | Guinea | 324 | GIN | x |  |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 011 | África occidental | Guinea-Bissau | 624 | GNB | x |  | x | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 011 | África occidental | Liberia | 430 | LBR | x |  |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 011 | África occidental | Malí | 466 | MLI | x | x |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 011 | África occidental | Mauritania | 478 | MRT | x |  |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 011 | África occidental | Níger | 562 | NER | x | x |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 011 | África occidental | Nigeria | 566 | NGA |  |  |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 011 | África occidental | Santa Elena | 654 | SHN |  |  |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 011 | África occidental | Senegal | 686 | SEN | x |  |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 011 | África occidental | Sierra Leona | 694 | SLE | x |  |  | `Developing`
001 | Mundo | 002 | África | 202 | África Subsahariana | 011 | África occidental | Togo | 768 | TGO | x |  |  | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 029 | El Caribe | Anguila | 660 | AIA |  |  | x | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 029 | El Caribe | Antigua y Barbuda | 028 | ATG |  |  | x | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 029 | El Caribe | Aruba | 533 | ABW |  |  | x | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 029 | El Caribe | Bahamas | 044 | BHS |  |  | x | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 029 | El Caribe | Barbados | 052 | BRB |  |  | x | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 029 | El Caribe | Bonaire, San Eustaquio y Saba | 535 | BES |  |  | x | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 029 | El Caribe | Islas Vírgenes Británicas | 092 | VGB |  |  | x | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 029 | El Caribe | Islas Caimán | 136 | CYM |  |  |  | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 029 | El Caribe | Cuba | 192 | CUB |  |  | x | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 029 | El Caribe | Curaçao | 531 | CUW |  |  | x | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 029 | El Caribe | Dominica | 212 | DMA |  |  | x | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 029 | El Caribe | República Dominicana | 214 | DOM |  |  | x | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 029 | El Caribe | Granada | 308 | GRD |  |  | x | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 029 | El Caribe | Guadalupe | 312 | GLP |  |  |  | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 029 | El Caribe | Haití | 332 | HTI | x |  | x | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 029 | El Caribe | Jamaica | 388 | JAM |  |  | x | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 029 | El Caribe | Martinica | 474 | MTQ |  |  |  | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 029 | El Caribe | Montserrat | 500 | MSR |  |  | x | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 029 | El Caribe | Puerto Rico | 630 | PRI |  |  | x | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 029 | El Caribe | San Bartolomé | 652 | BLM |  |  |  | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 029 | El Caribe | Saint Kitts y Nevis | 659 | KNA |  |  | x | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 029 | El Caribe | Santa Lucía | 662 | LCA |  |  | x | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 029 | El Caribe | San Martín (parte francesa) | 663 | MAF |  |  |  | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 029 | El Caribe | San Vicente y las Granadinas | 670 | VCT |  |  | x | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 029 | El Caribe | San Martín (parte holandés) | 534 | SXM |  |  | x | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 029 | El Caribe | Trinidad y Tabago | 780 | TTO |  |  | x | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 029 | El Caribe | Islas Turcas y Caicos | 796 | TCA |  |  |  | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 029 | El Caribe | Islas Vírgenes de los Estados Unidos | 850 | VIR |  |  | x | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 013 | América central | Belice | 084 | BLZ |  |  | x | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 013 | América central | Costa Rica | 188 | CRI |  |  |  | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 013 | América central | El Salvador | 222 | SLV |  |  |  | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 013 | América central | Guatemala | 320 | GTM |  |  |  | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 013 | América central | Honduras | 340 | HND |  |  |  | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 013 | América central | México | 484 | MEX |  |  |  | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 013 | América central | Nicaragua | 558 | NIC |  |  |  | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 013 | América central | Panamá | 591 | PAN |  |  |  | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 005 | América del Sur | Argentina | 032 | ARG |  |  |  | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 005 | América del Sur | Bolivia (Estado Plurinacional de) | 068 | BOL |  | x |  | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 005 | América del Sur | Isla Bouvet | 074 | BVT |  |  |  | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 005 | América del Sur | Brasil | 076 | BRA |  |  |  | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 005 | América del Sur | Chile | 152 | CHL |  |  |  | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 005 | América del Sur | Colombia | 170 | COL |  |  |  | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 005 | América del Sur | Ecuador | 218 | ECU |  |  |  | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 005 | América del Sur | Islas Malvinas (Falkland) | 238 | FLK |  |  |  | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 005 | América del Sur | Guayana Francesa | 254 | GUF |  |  |  | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 005 | América del Sur | Guyana | 328 | GUY |  |  | x | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 005 | América del Sur | Paraguay | 600 | PRY |  | x |  | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 005 | América del Sur | Perú | 604 | PER |  |  |  | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 005 | América del Sur | Georgia del Sur y las Islas Sandwich del Sur | 239 | SGS |  |  |  | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 005 | América del Sur | Suriname | 740 | SUR |  |  | x | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 005 | América del Sur | Uruguay | 858 | URY |  |  |  | `Developing`
001 | Mundo | 019 | Américas | 419 | América Latina y el Caribe | 005 | América del Sur | Venezuela (República Bolivariana de) | 862 | VEN |  |  |  | `Developing`
001 | Mundo | 019 | Américas | 021 | América septentrional |  |  | Bermuda | 060 | BMU |  |  |  | `Developed`
001 | Mundo | 019 | Américas | 021 | América septentrional |  |  | Canadá | 124 | CAN |  |  |  | `Developed`
001 | Mundo | 019 | Américas | 021 | América septentrional |  |  | Groenlandia | 304 | GRL |  |  |  | `Developed`
001 | Mundo | 019 | Américas | 021 | América septentrional |  |  | Saint Pierre y Miquelon | 666 | SPM |  |  |  | `Developed`
001 | Mundo | 019 | Américas | 021 | América septentrional |  |  | Estados Unidos de América | 840 | USA |  |  |  | `Developed`
001 | Mundo |  |  |  |  |  |  | Antártida | 010 | ATA |  |  |  |
001 | Mundo | 142 | Asia | 143 | Asia central |  |  | Kazajstán | 398 | KAZ |  | x |  | `Developing`
001 | Mundo | 142 | Asia | 143 | Asia central |  |  | Kirguistán | 417 | KGZ |  | x |  | `Developing`
001 | Mundo | 142 | Asia | 143 | Asia central |  |  | Tayikistán | 762 | TJK |  | x |  | `Developing`
001 | Mundo | 142 | Asia | 143 | Asia central |  |  | Turkmenistán | 795 | TKM |  | x |  | `Developing`
001 | Mundo | 142 | Asia | 143 | Asia central |  |  | Uzbekistán | 860 | UZB |  | x |  | `Developing`
001 | Mundo | 142 | Asia | 030 | Asia oriental |  |  | China | 156 | CHN |  |  |  | `Developing`
001 | Mundo | 142 | Asia | 030 | Asia oriental |  |  | China, región administrativa especial de Hong Kong | 344 | HKG |  |  |  | `Developing`
001 | Mundo | 142 | Asia | 030 | Asia oriental |  |  | China, región administrativa especial de Macao | 446 | MAC |  |  |  | `Developing`
001 | Mundo | 142 | Asia | 030 | Asia oriental |  |  | República Popular Democrática de Corea | 408 | PRK |  |  |  | `Developing`
001 | Mundo | 142 | Asia | 030 | Asia oriental |  |  | Japón | 392 | JPN |  |  |  | `Developed`
001 | Mundo | 142 | Asia | 030 | Asia oriental |  |  | Mongolia | 496 | MNG |  | x |  | `Developing`
001 | Mundo | 142 | Asia | 030 | Asia oriental |  |  | República de Corea | 410 | KOR |  |  |  | `Developing`
001 | Mundo | 142 | Asia | 035 | Asia sudoriental |  |  | Brunei Darussalam | 096 | BRN |  |  |  | `Developing`
001 | Mundo | 142 | Asia | 035 | Asia sudoriental |  |  | Camboya | 116 | KHM | x |  |  | `Developing`
001 | Mundo | 142 | Asia | 035 | Asia sudoriental |  |  | Indonesia | 360 | IDN |  |  |  | `Developing`
001 | Mundo | 142 | Asia | 035 | Asia sudoriental |  |  | República Democrática Popular Lao | 418 | LAO | x | x |  | `Developing`
001 | Mundo | 142 | Asia | 035 | Asia sudoriental |  |  | Malasia | 458 | MYS |  |  |  | `Developing`
001 | Mundo | 142 | Asia | 035 | Asia sudoriental |  |  | Myanmar | 104 | MMR | x |  |  | `Developing`
001 | Mundo | 142 | Asia | 035 | Asia sudoriental |  |  | Filipinas | 608 | PHL |  |  |  | `Developing`
001 | Mundo | 142 | Asia | 035 | Asia sudoriental |  |  | Singapur | 702 | SGP |  |  | x | `Developing`
001 | Mundo | 142 | Asia | 035 | Asia sudoriental |  |  | Tailandia | 764 | THA |  |  |  | `Developing`
001 | Mundo | 142 | Asia | 035 | Asia sudoriental |  |  | Timor-Leste | 626 | TLS | x |  | x | `Developing`
001 | Mundo | 142 | Asia | 035 | Asia sudoriental |  |  | Viet Nam | 704 | VNM |  |  |  | `Developing`
001 | Mundo | 142 | Asia | 034 | Asia meridional |  |  | Afganistán | 004 | AFG | x | x |  | `Developing`
001 | Mundo | 142 | Asia | 034 | Asia meridional |  |  | Bangladesh | 050 | BGD | x |  |  | `Developing`
001 | Mundo | 142 | Asia | 034 | Asia meridional |  |  | Bhután | 064 | BTN | x | x |  | `Developing`
001 | Mundo | 142 | Asia | 034 | Asia meridional |  |  | India | 356 | IND |  |  |  | `Developing`
001 | Mundo | 142 | Asia | 034 | Asia meridional |  |  | Irán (República Islámica del) | 364 | IRN |  |  |  | `Developing`
001 | Mundo | 142 | Asia | 034 | Asia meridional |  |  | Maldivas | 462 | MDV |  |  | x | `Developing`
001 | Mundo | 142 | Asia | 034 | Asia meridional |  |  | Nepal | 524 | NPL | x | x |  | `Developing`
001 | Mundo | 142 | Asia | 034 | Asia meridional |  |  | Pakistán | 586 | PAK |  |  |  | `Developing`
001 | Mundo | 142 | Asia | 034 | Asia meridional |  |  | Sri Lanka | 144 | LKA |  |  |  | `Developing`
001 | Mundo | 142 | Asia | 145 | Asia occidental |  |  | Armenia | 051 | ARM |  | x |  | `Developing`
001 | Mundo | 142 | Asia | 145 | Asia occidental |  |  | Azerbaiyán | 031 | AZE |  | x |  | `Developing`
001 | Mundo | 142 | Asia | 145 | Asia occidental |  |  | Bahrein | 048 | BHR |  |  |  | `Developing`
001 | Mundo | 142 | Asia | 145 | Asia occidental |  |  | Chipre | 196 | CYP |  |  |  | `Developing`
001 | Mundo | 142 | Asia | 145 | Asia occidental |  |  | Georgia | 268 | GEO |  |  |  | `Developing`
001 | Mundo | 142 | Asia | 145 | Asia occidental |  |  | Iraq | 368 | IRQ |  |  |  | `Developing`
001 | Mundo | 142 | Asia | 145 | Asia occidental |  |  | Israel | 376 | ISR |  |  |  | `Developing`
001 | Mundo | 142 | Asia | 145 | Asia occidental |  |  | Jordania | 400 | JOR |  |  |  | `Developing`
001 | Mundo | 142 | Asia | 145 | Asia occidental |  |  | Kuwait | 414 | KWT |  |  |  | `Developing`
001 | Mundo | 142 | Asia | 145 | Asia occidental |  |  | Líbano | 422 | LBN |  |  |  | `Developing`
001 | Mundo | 142 | Asia | 145 | Asia occidental |  |  | Omán | 512 | OMN |  |  |  | `Developing`
001 | Mundo | 142 | Asia | 145 | Asia occidental |  |  | Qatar | 634 | QAT |  |  |  | `Developing`
001 | Mundo | 142 | Asia | 145 | Asia occidental |  |  | Arabia Saudita | 682 | SAU |  |  |  | `Developing`
001 | Mundo | 142 | Asia | 145 | Asia occidental |  |  | Estado de Palestina | 275 | PSE |  |  |  | `Developing`
001 | Mundo | 142 | Asia | 145 | Asia occidental |  |  | República Árabe Siria | 760 | SYR |  |  |  | `Developing`
001 | Mundo | 142 | Asia | 145 | Asia occidental |  |  | Turquía | 792 | TUR |  |  |  | `Developing`
001 | Mundo | 142 | Asia | 145 | Asia occidental |  |  | Emiratos Árabes Unidos | 784 | ARE |  |  |  | `Developing`
001 | Mundo | 142 | Asia | 145 | Asia occidental |  |  | Yemen | 887 | YEM | x |  |  | `Developing`
001 | Mundo | 150 | Europa | 151 | Europa oriental |  |  | Belarús | 112 | BLR |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 151 | Europa oriental |  |  | Bulgaria | 100 | BGR |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 151 | Europa oriental |  |  | Chequia | 203 | CZE |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 151 | Europa oriental |  |  | Hungría | 348 | HUN |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 151 | Europa oriental |  |  | Polonia | 616 | POL |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 151 | Europa oriental |  |  | República de Moldova | 498 | MDA |  | x |  | `Developed`
001 | Mundo | 150 | Europa | 151 | Europa oriental |  |  | Rumania | 642 | ROU |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 151 | Europa oriental |  |  | Federación de Rusia | 643 | RUS |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 151 | Europa oriental |  |  | Eslovaquia | 703 | SVK |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 151 | Europa oriental |  |  | Ucrania | 804 | UKR |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 154 | Europa septentrional |  |  | Islas Åland | 248 | ALA |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 154 | Europa septentrional | 830 | Islas Anglonormandas | Guernsey | 831 | GGY |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 154 | Europa septentrional | 830 | Islas Anglonormandas | Jersey | 832 | JEY |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 154 | Europa septentrional | 830 | Islas Anglonormandas | Sark | 680 |  |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 154 | Europa septentrional |  |  | Dinamarca | 208 | DNK |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 154 | Europa septentrional |  |  | Estonia | 233 | EST |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 154 | Europa septentrional |  |  | Islas Feroe | 234 | FRO |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 154 | Europa septentrional |  |  | Finlandia | 246 | FIN |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 154 | Europa septentrional |  |  | Islandia | 352 | ISL |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 154 | Europa septentrional |  |  | Irlanda | 372 | IRL |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 154 | Europa septentrional |  |  | Isla de Man | 833 | IMN |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 154 | Europa septentrional |  |  | Letonia | 428 | LVA |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 154 | Europa septentrional |  |  | Lituania | 440 | LTU |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 154 | Europa septentrional |  |  | Noruega | 578 | NOR |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 154 | Europa septentrional |  |  | Islas Svalbard y Jan Mayen | 744 | SJM |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 154 | Europa septentrional |  |  | Suecia | 752 | SWE |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 154 | Europa septentrional |  |  | Reino Unido de Gran Bretaña e Irlanda del Norte | 826 | GBR |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 039 | Europa meridional |  |  | Albania | 008 | ALB |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 039 | Europa meridional |  |  | Andorra | 020 | AND |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 039 | Europa meridional |  |  | Bosnia y Herzegovina | 070 | BIH |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 039 | Europa meridional |  |  | Croacia | 191 | HRV |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 039 | Europa meridional |  |  | Gibraltar | 292 | GIB |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 039 | Europa meridional |  |  | Grecia | 300 | GRC |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 039 | Europa meridional |  |  | Santa Sede | 336 | VAT |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 039 | Europa meridional |  |  | Italia | 380 | ITA |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 039 | Europa meridional |  |  | Malta | 470 | MLT |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 039 | Europa meridional |  |  | Montenegro | 499 | MNE |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 039 | Europa meridional |  |  | Portugal | 620 | PRT |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 039 | Europa meridional |  |  | San Marino | 674 | SMR |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 039 | Europa meridional |  |  | Serbia | 688 | SRB |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 039 | Europa meridional |  |  | Eslovenia | 705 | SVN |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 039 | Europa meridional |  |  | España | 724 | ESP |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 039 | Europa meridional |  |  | ex República Yugoslava de Macedonia | 807 | MKD |  | x |  | `Developed`
001 | Mundo | 150 | Europa | 155 | Europa occidental |  |  | Austria | 040 | AUT |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 155 | Europa occidental |  |  | Bélgica | 056 | BEL |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 155 | Europa occidental |  |  | Francia | 250 | FRA |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 155 | Europa occidental |  |  | Alemania | 276 | DEU |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 155 | Europa occidental |  |  | Liechtenstein | 438 | LIE |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 155 | Europa occidental |  |  | Luxemburgo | 442 | LUX |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 155 | Europa occidental |  |  | Mónaco | 492 | MCO |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 155 | Europa occidental |  |  | Países Bajos | 528 | NLD |  |  |  | `Developed`
001 | Mundo | 150 | Europa | 155 | Europa occidental |  |  | Suiza | 756 | CHE |  |  |  | `Developed`
001 | Mundo | 009 | Oceanía | 053 | Australia y Nueva Zelandia |  |  | Australia | 036 | AUS |  |  |  | `Developed`
001 | Mundo | 009 | Oceanía | 053 | Australia y Nueva Zelandia |  |  | Isla de Navidad | 162 | CXR |  |  |  | `Developed`
001 | Mundo | 009 | Oceanía | 053 | Australia y Nueva Zelandia |  |  | Islas Cocos (Keeling) | 166 | CCK |  |  |  | `Developed`
001 | Mundo | 009 | Oceanía | 053 | Australia y Nueva Zelandia |  |  | Islas Heard y McDonald | 334 | HMD |  |  |  | `Developed`
001 | Mundo | 009 | Oceanía | 053 | Australia y Nueva Zelandia |  |  | Nueva Zelandia | 554 | NZL |  |  |  | `Developed`
001 | Mundo | 009 | Oceanía | 053 | Australia y Nueva Zelandia |  |  | Islas Norfolk | 574 | NFK |  |  |  | `Developed`
001 | Mundo | 009 | Oceanía | 054 | Melanesia |  |  | Fiji | 242 | FJI |  |  | x | `Developing`
001 | Mundo | 009 | Oceanía | 054 | Melanesia |  |  | Nueva Caledonia | 540 | NCL |  |  | x | `Developing`
001 | Mundo | 009 | Oceanía | 054 | Melanesia |  |  | Papua Nueva Guinea | 598 | PNG |  |  | x | `Developing`
001 | Mundo | 009 | Oceanía | 054 | Melanesia |  |  | Islas Salomón | 090 | SLB | x |  | x | `Developing`
001 | Mundo | 009 | Oceanía | 054 | Melanesia |  |  | Vanuatu | 548 | VUT | x |  | x | `Developing`
001 | Mundo | 009 | Oceanía | 057 | Micronesia |  |  | Guam | 316 | GUM |  |  | x | `Developing`
001 | Mundo | 009 | Oceanía | 057 | Micronesia |  |  | Kiribati | 296 | KIR | x |  | x | `Developing`
001 | Mundo | 009 | Oceanía | 057 | Micronesia |  |  | Islas Marshall | 584 | MHL |  |  | x | `Developing`
001 | Mundo | 009 | Oceanía | 057 | Micronesia |  |  | Micronesia (Estados Federados de) | 583 | FSM |  |  | x | `Developing`
001 | Mundo | 009 | Oceanía | 057 | Micronesia |  |  | Nauru | 520 | NRU |  |  | x | `Developing`
001 | Mundo | 009 | Oceanía | 057 | Micronesia |  |  | Islas Marianas Septentrionales | 580 | MNP |  |  | x | `Developing`
001 | Mundo | 009 | Oceanía | 057 | Micronesia |  |  | Palau | 585 | PLW |  |  | x | `Developing`
001 | Mundo | 009 | Oceanía | 057 | Micronesia |  |  | Islas menores alejadas de Estados Unidos | 581 | UMI |  |  |  | `Developing`
001 | Mundo | 009 | Oceanía | 061 | Polinesia |  |  | Samoa Americana | 016 | ASM |  |  | x | `Developing`
001 | Mundo | 009 | Oceanía | 061 | Polinesia |  |  | Islas Cook | 184 | COK |  |  | x | `Developing`
001 | Mundo | 009 | Oceanía | 061 | Polinesia |  |  | Polinesia Francesa | 258 | PYF |  |  | x | `Developing`
001 | Mundo | 009 | Oceanía | 061 | Polinesia |  |  | Niue | 570 | NIU |  |  | x | `Developing`
001 | Mundo | 009 | Oceanía | 061 | Polinesia |  |  | Pitcairn | 612 | PCN |  |  |  | `Developing`
001 | Mundo | 009 | Oceanía | 061 | Polinesia |  |  | Samoa | 882 | WSM |  |  | x | `Developing`
001 | Mundo | 009 | Oceanía | 061 | Polinesia |  |  | Tokelau | 772 | TKL |  |  |  | `Developing`
001 | Mundo | 009 | Oceanía | 061 | Polinesia |  |  | Tonga | 776 | TON |  |  | x | `Developing`
001 | Mundo | 009 | Oceanía | 061 | Polinesia |  |  | Tuvalu | 798 | TUV | x |  | x | `Developing`
001 | Mundo | 009 | Oceanía | 061 | Polinesia |  |  | Islas Wallis y Futuna | 876 | WLF |  |  |  | `Developing`

Global Code | Global Name | Region Code | Region Name | Sub-region Code | Sub-region Name | Intermediate Region Code | Intermediate Region Name | Country or Area | M49 Code | ISO-alpha3 Code | Least Developed Countries (LDC) | Land Locked Developing Countries (LLDC) | Small Island Developing States (SIDS) | Developed / Developing Countries
001 | العالم | 002 | أفريقيا | 015 | أفريقيا الشمالية |  |  | الجزائر | 012 | DZA |  |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 015 | أفريقيا الشمالية |  |  | مصر | 818 | EGY |  |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 015 | أفريقيا الشمالية |  |  | ليبيا | 434 | LBY |  |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 015 | أفريقيا الشمالية |  |  | المغرب | 504 | MAR |  |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 015 | أفريقيا الشمالية |  |  | السودان | 729 | SDN | x |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 015 | أفريقيا الشمالية |  |  | تونس | 788 | TUN |  |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 015 | أفريقيا الشمالية |  |  | الصحراء الغربية | 732 | ESH |  |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 014 | شرق أفريقيا | المحيط الهندي الإقليم البريطاني في | 086 | IOT |  |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 014 | شرق أفريقيا | بوروندي | 108 | BDI | x | x |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 014 | شرق أفريقيا | جزر القمر | 174 | COM | x |  | x | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 014 | شرق أفريقيا | جيبوتي | 262 | DJI | x |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 014 | شرق أفريقيا | إريتريا | 232 | ERI | x |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 014 | شرق أفريقيا | إثيوبيا | 231 | ETH | x | x |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 014 | شرق أفريقيا | الأراضي الفرنسية الجنوبية الجنوبية | 260 | ATF |  |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 014 | شرق أفريقيا | كينيا | 404 | KEN |  |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 014 | شرق أفريقيا | مدغشقر | 450 | MDG | x |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 014 | شرق أفريقيا | ملاوي | 454 | MWI | x | x |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 014 | شرق أفريقيا | موريشيوس | 480 | MUS |  |  | x | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 014 | شرق أفريقيا | جزيرة مايوت | 175 | MYT |  |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 014 | شرق أفريقيا | موزامبيق | 508 | MOZ | x |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 014 | شرق أفريقيا | ريونيون | 638 | REU |  |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 014 | شرق أفريقيا | رواندا | 646 | RWA | x | x |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 014 | شرق أفريقيا | سيشيل | 690 | SYC |  |  | x | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 014 | شرق أفريقيا | الصومال | 706 | SOM | x |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 014 | شرق أفريقيا | جنوب السودان | 728 | SSD | x | x |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 014 | شرق أفريقيا | أوغندا | 800 | UGA | x | x |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 014 | شرق أفريقيا | جمهورية تنزانيا المتحدة | 834 | TZA | x |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 014 | شرق أفريقيا | زامبيا | 894 | ZMB | x | x |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 014 | شرق أفريقيا | زمبابوي | 716 | ZWE |  | x |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 017 | وسط أفريقيا | أنغولا | 024 | AGO | x |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 017 | وسط أفريقيا | الكاميرون | 120 | CMR |  |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 017 | وسط أفريقيا | جمهورية أفريقيا الوسطى | 140 | CAF | x | x |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 017 | وسط أفريقيا | تشاد | 148 | TCD | x | x |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 017 | وسط أفريقيا | الكونغو | 178 | COG |  |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 017 | وسط أفريقيا | جمهورية الكونغو الديمقراطية | 180 | COD | x |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 017 | وسط أفريقيا | غينيا الاستوائية | 226 | GNQ | x |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 017 | وسط أفريقيا | غابون | 266 | GAB |  |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 017 | وسط أفريقيا | سان تومي وبرينسيبي | 678 | STP | x |  | x | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 018 | الجنوب الأفريقي | بوتسوانا | 072 | BWA |  | x |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 018 | الجنوب الأفريقي | ليسوتو | 426 | LSO | x | x |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 018 | الجنوب الأفريقي | ناميبيا | 516 | NAM |  |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 018 | الجنوب الأفريقي | جنوب أفريقيا | 710 | ZAF |  |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 018 | الجنوب الأفريقي | سوازيلند | 748 | SWZ |  | x |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 011 | غرب أفريقيا | بنن | 204 | BEN | x |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 011 | غرب أفريقيا | بوركينا فاسو | 854 | BFA | x | x |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 011 | غرب أفريقيا | كابو فيردي | 132 | CPV |  |  | x | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 011 | غرب أفريقيا | كوت ديفوار | 384 | CIV |  |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 011 | غرب أفريقيا | غامبيا | 270 | GMB | x |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 011 | غرب أفريقيا | غانا | 288 | GHA |  |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 011 | غرب أفريقيا | غينيا | 324 | GIN | x |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 011 | غرب أفريقيا | غينيا - بيساو | 624 | GNB | x |  | x | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 011 | غرب أفريقيا | ليبريا | 430 | LBR | x |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 011 | غرب أفريقيا | مالي | 466 | MLI | x | x |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 011 | غرب أفريقيا | موريتانيا | 478 | MRT | x |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 011 | غرب أفريقيا | النيجر | 562 | NER | x | x |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 011 | غرب أفريقيا | نيجيريا | 566 | NGA |  |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 011 | غرب أفريقيا | سانت هيلانة | 654 | SHN |  |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 011 | غرب أفريقيا | السنغال | 686 | SEN | x |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 011 | غرب أفريقيا | سيراليون | 694 | SLE | x |  |  | `Developing`
001 | العالم | 002 | أفريقيا | 202 | أفريقيا جنوب الصحراء الكبرى | 011 | غرب أفريقيا | توغو | 768 | TGO | x |  |  | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 029 | منطقة البحر الكاريبي | أنغيلا | 660 | AIA |  |  | x | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 029 | منطقة البحر الكاريبي | أنتيغوا وبربودا | 028 | ATG |  |  | x | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 029 | منطقة البحر الكاريبي | أروبا | 533 | ABW |  |  | x | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 029 | منطقة البحر الكاريبي | جزر البهاما | 044 | BHS |  |  | x | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 029 | منطقة البحر الكاريبي | بربادوس | 052 | BRB |  |  | x | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 029 | منطقة البحر الكاريبي | بونير وسان يوستاتيوس وسابا | 535 | BES |  |  | x | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 029 | منطقة البحر الكاريبي | جزر فرجن البريطانية | 092 | VGB |  |  | x | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 029 | منطقة البحر الكاريبي | جزر كايمان | 136 | CYM |  |  |  | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 029 | منطقة البحر الكاريبي | كوبا | 192 | CUB |  |  | x | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 029 | منطقة البحر الكاريبي | كوراساو | 531 | CUW |  |  | x | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 029 | منطقة البحر الكاريبي | دومينيكا | 212 | DMA |  |  | x | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 029 | منطقة البحر الكاريبي | الجمهورية الدومينيكية | 214 | DOM |  |  | x | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 029 | منطقة البحر الكاريبي | غرينادا | 308 | GRD |  |  | x | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 029 | منطقة البحر الكاريبي | غواديلوب | 312 | GLP |  |  |  | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 029 | منطقة البحر الكاريبي | هايتي | 332 | HTI | x |  | x | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 029 | منطقة البحر الكاريبي | جامايكا | 388 | JAM |  |  | x | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 029 | منطقة البحر الكاريبي | مارتينيك | 474 | MTQ |  |  |  | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 029 | منطقة البحر الكاريبي | مونتسيرات | 500 | MSR |  |  | x | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 029 | منطقة البحر الكاريبي | بورتوريكو | 630 | PRI |  |  | x | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 029 | منطقة البحر الكاريبي | سان بارتليمي | 652 | BLM |  |  |  | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 029 | منطقة البحر الكاريبي | سانت كيتس ونيفس | 659 | KNA |  |  | x | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 029 | منطقة البحر الكاريبي | سانت لوسيا | 662 | LCA |  |  | x | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 029 | منطقة البحر الكاريبي | سان مارتن | 663 | MAF |  |  |  | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 029 | منطقة البحر الكاريبي | سانت فنسنت وجزر غرينادين | 670 | VCT |  |  | x | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 029 | منطقة البحر الكاريبي | سانت مارتن | 534 | SXM |  |  | x | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 029 | منطقة البحر الكاريبي | ترينيداد وتوباغو | 780 | TTO |  |  | x | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 029 | منطقة البحر الكاريبي | جزر تركس وكايكوس | 796 | TCA |  |  |  | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 029 | منطقة البحر الكاريبي | جزر فرجن التابعة للولايات المتحدة | 850 | VIR |  |  | x | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 013 | أمريكا الوسطى | بليز | 084 | BLZ |  |  | x | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 013 | أمريكا الوسطى | كوستاريكا | 188 | CRI |  |  |  | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 013 | أمريكا الوسطى | السلفادور | 222 | SLV |  |  |  | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 013 | أمريكا الوسطى | غواتيمالا | 320 | GTM |  |  |  | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 013 | أمريكا الوسطى | هندوراس | 340 | HND |  |  |  | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 013 | أمريكا الوسطى | المكسيك | 484 | MEX |  |  |  | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 013 | أمريكا الوسطى | نيكاراغوا | 558 | NIC |  |  |  | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 013 | أمريكا الوسطى | بنما | 591 | PAN |  |  |  | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 005 | أمريكا الجنوبية | الأرجنتين | 032 | ARG |  |  |  | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 005 | أمريكا الجنوبية | بوليفيا (دولة - المتعددة القوميات) | 068 | BOL |  | x |  | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 005 | أمريكا الجنوبية | جزيرة بوفيت | 074 | BVT |  |  |  | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 005 | أمريكا الجنوبية | البرازيل | 076 | BRA |  |  |  | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 005 | أمريكا الجنوبية | شيلي | 152 | CHL |  |  |  | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 005 | أمريكا الجنوبية | كولومبيا | 170 | COL |  |  |  | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 005 | أمريكا الجنوبية | إكوادور | 218 | ECU |  |  |  | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 005 | أمريكا الجنوبية | جزر فوكلاند (مالفيناس) | 238 | FLK |  |  |  | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 005 | أمريكا الجنوبية | غيانا الفرنسية | 254 | GUF |  |  |  | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 005 | أمريكا الجنوبية | غيانا | 328 | GUY |  |  | x | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 005 | أمريكا الجنوبية | باراغواي | 600 | PRY |  | x |  | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 005 | أمريكا الجنوبية | بيرو | 604 | PER |  |  |  | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 005 | أمريكا الجنوبية | جورجيا الجنوبية وجزر ساندويتش الجنوبية | 239 | SGS |  |  |  | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 005 | أمريكا الجنوبية | سورينام | 740 | SUR |  |  | x | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 005 | أمريكا الجنوبية | أوروغواي | 858 | URY |  |  |  | `Developing`
001 | العالم | 019 | الأمريكتان | 419 | أمريكا اللاتينية ومنطقة البحر الكاريبي | 005 | أمريكا الجنوبية | فنزويلا (جمهورية - البوليفارية) | 862 | VEN |  |  |  | `Developing`
001 | العالم | 019 | الأمريكتان | 021 | أمريكا الشمالية |  |  | برمودا | 060 | BMU |  |  |  | `Developed`
001 | العالم | 019 | الأمريكتان | 021 | أمريكا الشمالية |  |  | كندا | 124 | CAN |  |  |  | `Developed`
001 | العالم | 019 | الأمريكتان | 021 | أمريكا الشمالية |  |  | غرينلند | 304 | GRL |  |  |  | `Developed`
001 | العالم | 019 | الأمريكتان | 021 | أمريكا الشمالية |  |  | سان بيار وميكلون | 666 | SPM |  |  |  | `Developed`
001 | العالم | 019 | الأمريكتان | 021 | أمريكا الشمالية |  |  | الولايات المتحدة الأمريكية | 840 | USA |  |  |  | `Developed`
001 | العالم |  |  |  |  |  |  | أنتاركتيكا | 010 | ATA |  |  |  |
001 | العالم | 142 | آسيا | 143 | آسيا الوسطى |  |  | كازاخستان | 398 | KAZ |  | x |  | `Developing`
001 | العالم | 142 | آسيا | 143 | آسيا الوسطى |  |  | قيرغيزستان | 417 | KGZ |  | x |  | `Developing`
001 | العالم | 142 | آسيا | 143 | آسيا الوسطى |  |  | طاجيكستان | 762 | TJK |  | x |  | `Developing`
001 | العالم | 142 | آسيا | 143 | آسيا الوسطى |  |  | تركمانستان | 795 | TKM |  | x |  | `Developing`
001 | العالم | 142 | آسيا | 143 | آسيا الوسطى |  |  | أوزبكستان | 860 | UZB |  | x |  | `Developing`
001 | العالم | 142 | آسيا | 030 | شرقي آسيا |  |  | الصين | 156 | CHN |  |  |  | `Developing`
001 | العالم | 142 | آسيا | 030 | شرقي آسيا |  |  | منطقة هونغ كونغ الصينية الإدارية الخاصة | 344 | HKG |  |  |  | `Developing`
001 | العالم | 142 | آسيا | 030 | شرقي آسيا |  |  | منطقة ماكاو الإدارية الخاصة التابعة للصين | 446 | MAC |  |  |  | `Developing`
001 | العالم | 142 | آسيا | 030 | شرقي آسيا |  |  | جمهورية كوريا الشعبية الديمقراطية | 408 | PRK |  |  |  | `Developing`
001 | العالم | 142 | آسيا | 030 | شرقي آسيا |  |  | اليابان | 392 | JPN |  |  |  | `Developed`
001 | العالم | 142 | آسيا | 030 | شرقي آسيا |  |  | منغوليا | 496 | MNG |  | x |  | `Developing`
001 | العالم | 142 | آسيا | 030 | شرقي آسيا |  |  | جمهورية كوريا | 410 | KOR |  |  |  | `Developing`
001 | العالم | 142 | آسيا | 035 | جنوب شرقي آسيا |  |  | بروني دار السلام | 096 | BRN |  |  |  | `Developing`
001 | العالم | 142 | آسيا | 035 | جنوب شرقي آسيا |  |  | كمبوديا | 116 | KHM | x |  |  | `Developing`
001 | العالم | 142 | آسيا | 035 | جنوب شرقي آسيا |  |  | إندونيسيا | 360 | IDN |  |  |  | `Developing`
001 | العالم | 142 | آسيا | 035 | جنوب شرقي آسيا |  |  | جمهورية لاو الديمقراطية الشعبية | 418 | LAO | x | x |  | `Developing`
001 | العالم | 142 | آسيا | 035 | جنوب شرقي آسيا |  |  | ماليزيا | 458 | MYS |  |  |  | `Developing`
001 | العالم | 142 | آسيا | 035 | جنوب شرقي آسيا |  |  | ميانمار | 104 | MMR | x |  |  | `Developing`
001 | العالم | 142 | آسيا | 035 | جنوب شرقي آسيا |  |  | الفلبين | 608 | PHL |  |  |  | `Developing`
001 | العالم | 142 | آسيا | 035 | جنوب شرقي آسيا |  |  | سنغافورة | 702 | SGP |  |  | x | `Developing`
001 | العالم | 142 | آسيا | 035 | جنوب شرقي آسيا |  |  | تايلند | 764 | THA |  |  |  | `Developing`
001 | العالم | 142 | آسيا | 035 | جنوب شرقي آسيا |  |  | تيمور- ليشتي | 626 | TLS | x |  | x | `Developing`
001 | العالم | 142 | آسيا | 035 | جنوب شرقي آسيا |  |  | فييت نام | 704 | VNM |  |  |  | `Developing`
001 | العالم | 142 | آسيا | 034 | جنوب آسيا |  |  | أفغانستان | 004 | AFG | x | x |  | `Developing`
001 | العالم | 142 | آسيا | 034 | جنوب آسيا |  |  | بنغلاديش | 050 | BGD | x |  |  | `Developing`
001 | العالم | 142 | آسيا | 034 | جنوب آسيا |  |  | بوتان | 064 | BTN | x | x |  | `Developing`
001 | العالم | 142 | آسيا | 034 | جنوب آسيا |  |  | الهند | 356 | IND |  |  |  | `Developing`
001 | العالم | 142 | آسيا | 034 | جنوب آسيا |  |  | إيران (جمهورية - الإسلامية) | 364 | IRN |  |  |  | `Developing`
001 | العالم | 142 | آسيا | 034 | جنوب آسيا |  |  | ملديف | 462 | MDV |  |  | x | `Developing`
001 | العالم | 142 | آسيا | 034 | جنوب آسيا |  |  | نيبال | 524 | NPL | x | x |  | `Developing`
001 | العالم | 142 | آسيا | 034 | جنوب آسيا |  |  | باكستان | 586 | PAK |  |  |  | `Developing`
001 | العالم | 142 | آسيا | 034 | جنوب آسيا |  |  | سري لانكا | 144 | LKA |  |  |  | `Developing`
001 | العالم | 142 | آسيا | 145 | غربي آسيا |  |  | أرمينيا | 051 | ARM |  | x |  | `Developing`
001 | العالم | 142 | آسيا | 145 | غربي آسيا |  |  | أذربيجان | 031 | AZE |  | x |  | `Developing`
001 | العالم | 142 | آسيا | 145 | غربي آسيا |  |  | البحرين | 048 | BHR |  |  |  | `Developing`
001 | العالم | 142 | آسيا | 145 | غربي آسيا |  |  | قبرص | 196 | CYP |  |  |  | `Developing`
001 | العالم | 142 | آسيا | 145 | غربي آسيا |  |  | جورجيا | 268 | GEO |  |  |  | `Developing`
001 | العالم | 142 | آسيا | 145 | غربي آسيا |  |  | العراق | 368 | IRQ |  |  |  | `Developing`
001 | العالم | 142 | آسيا | 145 | غربي آسيا |  |  | إسرائيل | 376 | ISR |  |  |  | `Developing`
001 | العالم | 142 | آسيا | 145 | غربي آسيا |  |  | الأردن | 400 | JOR |  |  |  | `Developing`
001 | العالم | 142 | آسيا | 145 | غربي آسيا |  |  | الكويت | 414 | KWT |  |  |  | `Developing`
001 | العالم | 142 | آسيا | 145 | غربي آسيا |  |  | لبنان | 422 | LBN |  |  |  | `Developing`
001 | العالم | 142 | آسيا | 145 | غربي آسيا |  |  | عمان | 512 | OMN |  |  |  | `Developing`
001 | العالم | 142 | آسيا | 145 | غربي آسيا |  |  | قطر | 634 | QAT |  |  |  | `Developing`
001 | العالم | 142 | آسيا | 145 | غربي آسيا |  |  | المملكة العربية السعودية | 682 | SAU |  |  |  | `Developing`
001 | العالم | 142 | آسيا | 145 | غربي آسيا |  |  | دولة فلسطين | 275 | PSE |  |  |  | `Developing`
001 | العالم | 142 | آسيا | 145 | غربي آسيا |  |  | الجمهورية العربية السورية | 760 | SYR |  |  |  | `Developing`
001 | العالم | 142 | آسيا | 145 | غربي آسيا |  |  | تركيا | 792 | TUR |  |  |  | `Developing`
001 | العالم | 142 | آسيا | 145 | غربي آسيا |  |  | الإمارات العربية المتحدة | 784 | ARE |  |  |  | `Developing`
001 | العالم | 142 | آسيا | 145 | غربي آسيا |  |  | اليمن | 887 | YEM | x |  |  | `Developing`
001 | العالم | 150 | أوروبا | 151 | أوروبا الشرقية |  |  | بيلاروس | 112 | BLR |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 151 | أوروبا الشرقية |  |  | بلغاريا | 100 | BGR |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 151 | أوروبا الشرقية |  |  | تشيكيا | 203 | CZE |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 151 | أوروبا الشرقية |  |  | هنغاريا | 348 | HUN |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 151 | أوروبا الشرقية |  |  | بولندا | 616 | POL |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 151 | أوروبا الشرقية |  |  | جمهورية مولدوفا | 498 | MDA |  | x |  | `Developed`
001 | العالم | 150 | أوروبا | 151 | أوروبا الشرقية |  |  | رومانيا | 642 | ROU |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 151 | أوروبا الشرقية |  |  | الاتحاد الروسي | 643 | RUS |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 151 | أوروبا الشرقية |  |  | سلوفاكيا | 703 | SVK |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 151 | أوروبا الشرقية |  |  | أوكرانيا | 804 | UKR |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 154 | أوروبا الشمالية |  |  | جزر ألاند | 248 | ALA |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 154 | أوروبا الشمالية | 830 | جزر تشانل | غيرنزي | 831 | GGY |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 154 | أوروبا الشمالية | 830 | جزر تشانل | جيرزي | 832 | JEY |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 154 | أوروبا الشمالية | 830 | جزر تشانل | سارك | 680 |  |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 154 | أوروبا الشمالية |  |  | الدانمرك | 208 | DNK |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 154 | أوروبا الشمالية |  |  | إستونيا | 233 | EST |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 154 | أوروبا الشمالية |  |  | جزر فايرو | 234 | FRO |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 154 | أوروبا الشمالية |  |  | فنلندا | 246 | FIN |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 154 | أوروبا الشمالية |  |  | آيسلندا | 352 | ISL |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 154 | أوروبا الشمالية |  |  | آيرلندا | 372 | IRL |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 154 | أوروبا الشمالية |  |  | جزيرة مان | 833 | IMN |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 154 | أوروبا الشمالية |  |  | لاتفيا | 428 | LVA |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 154 | أوروبا الشمالية |  |  | ليتوانيا | 440 | LTU |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 154 | أوروبا الشمالية |  |  | النرويج | 578 | NOR |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 154 | أوروبا الشمالية |  |  | جزر سفالبارد وجان ماين | 744 | SJM |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 154 | أوروبا الشمالية |  |  | السويد | 752 | SWE |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 154 | أوروبا الشمالية |  |  | المملكة المتحدة لبريطانيا العظمى وآيرلندا الشمالية | 826 | GBR |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 039 | أوروبا الجنوبية |  |  | ألبانيا | 008 | ALB |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 039 | أوروبا الجنوبية |  |  | أندورا | 020 | AND |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 039 | أوروبا الجنوبية |  |  | البوسنة والهرسك | 070 | BIH |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 039 | أوروبا الجنوبية |  |  | كرواتيا | 191 | HRV |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 039 | أوروبا الجنوبية |  |  | جبل طارق | 292 | GIB |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 039 | أوروبا الجنوبية |  |  | اليونان | 300 | GRC |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 039 | أوروبا الجنوبية |  |  | الكرسي الرسولي | 336 | VAT |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 039 | أوروبا الجنوبية |  |  | إيطاليا | 380 | ITA |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 039 | أوروبا الجنوبية |  |  | مالطة | 470 | MLT |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 039 | أوروبا الجنوبية |  |  | الجبل الأسود | 499 | MNE |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 039 | أوروبا الجنوبية |  |  | البرتغال | 620 | PRT |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 039 | أوروبا الجنوبية |  |  | سان مارينو | 674 | SMR |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 039 | أوروبا الجنوبية |  |  | صربيا | 688 | SRB |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 039 | أوروبا الجنوبية |  |  | سلوفينيا | 705 | SVN |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 039 | أوروبا الجنوبية |  |  | إسبانيا | 724 | ESP |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 039 | أوروبا الجنوبية |  |  | جمهورية مقدونيا اليوغوسلافية سابقاً | 807 | MKD |  | x |  | `Developed`
001 | العالم | 150 | أوروبا | 155 | أوروبا الغربية |  |  | النمسا | 040 | AUT |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 155 | أوروبا الغربية |  |  | بلجيكا | 056 | BEL |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 155 | أوروبا الغربية |  |  | فرنسا | 250 | FRA |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 155 | أوروبا الغربية |  |  | ألمانيا | 276 | DEU |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 155 | أوروبا الغربية |  |  | ليختنشتاين | 438 | LIE |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 155 | أوروبا الغربية |  |  | لكسمبرغ | 442 | LUX |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 155 | أوروبا الغربية |  |  | موناكو | 492 | MCO |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 155 | أوروبا الغربية |  |  | هولندا | 528 | NLD |  |  |  | `Developed`
001 | العالم | 150 | أوروبا | 155 | أوروبا الغربية |  |  | سويسرا | 756 | CHE |  |  |  | `Developed`
001 | العالم | 009 | أوقيانوسيا | 053 | استراليا ونيوزيلندا |  |  | أستراليا | 036 | AUS |  |  |  | `Developed`
001 | العالم | 009 | أوقيانوسيا | 053 | استراليا ونيوزيلندا |  |  | جزيرة كريسماس | 162 | CXR |  |  |  | `Developed`
001 | العالم | 009 | أوقيانوسيا | 053 | استراليا ونيوزيلندا |  |  | جزر كوكوس (كيلينغ) | 166 | CCK |  |  |  | `Developed`
001 | العالم | 009 | أوقيانوسيا | 053 | استراليا ونيوزيلندا |  |  | جزيرة هيرد وجزر ماكدونالد | 334 | HMD |  |  |  | `Developed`
001 | العالم | 009 | أوقيانوسيا | 053 | استراليا ونيوزيلندا |  |  | نيوزيلندا | 554 | NZL |  |  |  | `Developed`
001 | العالم | 009 | أوقيانوسيا | 053 | استراليا ونيوزيلندا |  |  | جزيرة نورفلك | 574 | NFK |  |  |  | `Developed`
001 | العالم | 009 | أوقيانوسيا | 054 | ميلانيزيا |  |  | فيجي | 242 | FJI |  |  | x | `Developing`
001 | العالم | 009 | أوقيانوسيا | 054 | ميلانيزيا |  |  | كاليدونيا الجديدة | 540 | NCL |  |  | x | `Developing`
001 | العالم | 009 | أوقيانوسيا | 054 | ميلانيزيا |  |  | بابوا غينيا الجديدة | 598 | PNG |  |  | x | `Developing`
001 | العالم | 009 | أوقيانوسيا | 054 | ميلانيزيا |  |  | جزر سليمان | 090 | SLB | x |  | x | `Developing`
001 | العالم | 009 | أوقيانوسيا | 054 | ميلانيزيا |  |  | فانواتو | 548 | VUT | x |  | x | `Developing`
001 | العالم | 009 | أوقيانوسيا | 057 | ميكرونيزيا |  |  | غوام | 316 | GUM |  |  | x | `Developing`
001 | العالم | 009 | أوقيانوسيا | 057 | ميكرونيزيا |  |  | كيريباس | 296 | KIR | x |  | x | `Developing`
001 | العالم | 009 | أوقيانوسيا | 057 | ميكرونيزيا |  |  | جزر مارشال | 584 | MHL |  |  | x | `Developing`
001 | العالم | 009 | أوقيانوسيا | 057 | ميكرونيزيا |  |  | ميكرونيزيا (ولايات - الموحدة) | 583 | FSM |  |  | x | `Developing`
001 | العالم | 009 | أوقيانوسيا | 057 | ميكرونيزيا |  |  | ناورو | 520 | NRU |  |  | x | `Developing`
001 | العالم | 009 | أوقيانوسيا | 057 | ميكرونيزيا |  |  | جزر ماريانا الشمالية | 580 | MNP |  |  | x | `Developing`
001 | العالم | 009 | أوقيانوسيا | 057 | ميكرونيزيا |  |  | بالاو | 585 | PLW |  |  | x | `Developing`
001 | العالم | 009 | أوقيانوسيا | 057 | ميكرونيزيا |  |  | نائية التابعة للولايات المتحدة | 581 | UMI |  |  |  | `Developing`
001 | العالم | 009 | أوقيانوسيا | 061 | بولينيزيا |  |  | ساموا الأمريكية | 016 | ASM |  |  | x | `Developing`
001 | العالم | 009 | أوقيانوسيا | 061 | بولينيزيا |  |  | جزر كوك | 184 | COK |  |  | x | `Developing`
001 | العالم | 009 | أوقيانوسيا | 061 | بولينيزيا |  |  | بولينيزيا الفرنسية | 258 | PYF |  |  | x | `Developing`
001 | العالم | 009 | أوقيانوسيا | 061 | بولينيزيا |  |  | نيوي | 570 | NIU |  |  | x | `Developing`
001 | العالم | 009 | أوقيانوسيا | 061 | بولينيزيا |  |  | بيتكيرن | 612 | PCN |  |  |  | `Developing`
001 | العالم | 009 | أوقيانوسيا | 061 | بولينيزيا |  |  | ساموا | 882 | WSM |  |  | x | `Developing`
001 | العالم | 009 | أوقيانوسيا | 061 | بولينيزيا |  |  | توكيلاو | 772 | TKL |  |  |  | `Developing`
001 | العالم | 009 | أوقيانوسيا | 061 | بولينيزيا |  |  | تونغا | 776 | TON |  |  | x | `Developing`
001 | العالم | 009 | أوقيانوسيا | 061 | بولينيزيا |  |  | توفالو | 798 | TUV | x |  | x | `Developing`
001 | العالم | 009 | أوقيانوسيا | 061 | بولينيزيا |  |  | جزر واليس وفوتونا | 876 | WLF |  |  |  | `Developing`